@@ -40,6 +40,38 @@ TEST(server, create_pipe_buffers) {
     }
 }
 
+TEST(server, schedule) {
+    int ret;
+    Server serv(Server::MODE_PROCESS);
+    serv.worker_num = 6;
+    serv.dispatch_mode = Server::DISPATCH_IDLE_WORKER;
+    ret = serv.create();
+    ASSERT_EQ(SW_OK, ret);
+
+    for (uint32_t i = 0; i < serv.worker_num; i++) {
+        serv.workers[i].status = SW_WORKER_BUSY;
+    }
+
+    std::set<int> _worker_id_set;
+
+    for (uint32_t i = 0; i < serv.worker_num; i++) {
+        auto worker_id = serv.schedule_worker(i*13, nullptr);
+        _worker_id_set.insert(worker_id);
+    }
+    ASSERT_EQ(_worker_id_set.size(), serv.worker_num);
+   
+    for (uint32_t i = 1; i < serv.worker_num - 1; i++) {
+        serv.workers[i].status = SW_WORKER_IDLE;
+    }
+
+    _worker_id_set.clear();
+    for (uint32_t i = 0; i < serv.worker_num; i++) {
+        auto worker_id = serv.schedule_worker(i*13, nullptr);
+        _worker_id_set.insert(worker_id);
+    }
+    ASSERT_EQ(_worker_id_set.size(), serv.worker_num - 2);
+}
+
 static const char *packet = "hello world\n";
 
 TEST(server, base) {
@@ -57,7 +89,7 @@ TEST(server, base) {
     ASSERT_EQ(serv.create(), SW_OK);
 
     std::thread t1([&]() {
-        swSignal_none();
+        swoole_signal_block_all();
 
         lock.lock();
 
@@ -99,7 +131,7 @@ TEST(server, process) {
 
     ListenPort *port = serv.add_port(SW_SOCK_TCP, TEST_HOST, 0);
     if (!port) {
-        swWarn("listen failed, [error=%d]", swoole_get_last_error());
+        swoole_warning("listen failed, [error=%d]", swoole_get_last_error());
         exit(2);
     }
 
@@ -107,7 +139,7 @@ TEST(server, process) {
 
     serv.onStart = [&lock](swServer *serv) {
         thread t1([=]() {
-            swSignal_none();
+            swoole_signal_block_all();
 
             lock->lock();
 
@@ -153,9 +185,9 @@ TEST(server, ssl) {
     Mutex *lock = new Mutex(Mutex::PROCESS_SHARED);
     lock->lock();
 
-    ListenPort *port = serv.add_port((enum swSocket_type )(SW_SOCK_TCP | SW_SOCK_SSL), TEST_HOST, 0);
+    ListenPort *port = serv.add_port((enum swSocketType )(SW_SOCK_TCP | SW_SOCK_SSL), TEST_HOST, 0);
     if (!port) {
-        swWarn("listen failed, [error=%d]", swoole_get_last_error());
+        swoole_warning("listen failed, [error=%d]", swoole_get_last_error());
         exit(2);
     }
 
@@ -167,14 +199,14 @@ TEST(server, ssl) {
 
     serv.onStart = [&lock](Server *serv) {
         thread t1([=]() {
-            swSignal_none();
+            swoole_signal_block_all();
 
             lock->lock();
 
             ListenPort *port = serv->get_primary_port();
 
             EXPECT_EQ(port->ssl, 1);
-            EXPECT_EQ(swSSL_is_thread_safety(), true);
+            EXPECT_EQ(swoole_ssl_is_thread_safety(), true);
 
             swoole::network::SyncClient c(SW_SOCK_TCP);
             c.connect(TEST_HOST, port->port);
@@ -216,9 +248,9 @@ TEST(server, dtls) {
     Mutex *lock = new Mutex(Mutex::PROCESS_SHARED);
     lock->lock();
 
-    ListenPort *port = serv.add_port((enum swSocket_type )(SW_SOCK_UDP | SW_SOCK_SSL), TEST_HOST, 0);
+    ListenPort *port = serv.add_port((enum swSocketType )(SW_SOCK_UDP | SW_SOCK_SSL), TEST_HOST, 0);
     if (!port) {
-        swWarn("listen failed, [error=%d]", swoole_get_last_error());
+        swoole_warning("listen failed, [error=%d]", swoole_get_last_error());
         exit(2);
     }
 
@@ -230,7 +262,7 @@ TEST(server, dtls) {
 
     serv.onStart = [&lock](Server *serv) {
         thread t1([=]() {
-            swSignal_none();
+            swoole_signal_block_all();
 
             lock->lock();
 
@@ -275,7 +307,7 @@ TEST(server, task_worker) {
 
     swListenPort *port = serv.add_port(SW_SOCK_TCP, TEST_HOST, 0);
     if (!port) {
-        swWarn("listen failed, [error=%d]", swoole_get_last_error());
+        swoole_warning("listen failed, [error=%d]", swoole_get_last_error());
         exit(2);
     }
 
@@ -298,7 +330,7 @@ TEST(server, task_worker) {
     swEventData buf;
     memset(&buf.info, 0, sizeof(buf.info));
 
-    swTask_type(&buf) |= SW_TASK_NOREPLY;
+    SW_TASK_TYPE(&buf) |= SW_TASK_NOREPLY;
     buf.info.len = strlen(packet);
     memcpy(buf.data, packet, strlen(packet));
 
