@@ -81,9 +81,9 @@ extern zend_string **sw_zend_known_strings;
 
 
 SW_API bool php_swoole_is_enable_coroutine();
-SW_API zend_object *php_swoole_create_socket_from_fd(int fd, enum swSocket_type type);
+SW_API zend_object *php_swoole_create_socket_from_fd(int fd, enum swSocketType type);
 SW_API bool php_swoole_export_socket(zval *zobject, swoole::coroutine::Socket *_socket);
-SW_API zend_object *php_swoole_dup_socket(int fd, enum swSocket_type type);
+SW_API zend_object *php_swoole_dup_socket(int fd, enum swSocketType type);
 SW_API void php_swoole_init_socket_object(zval *zobject, swoole::coroutine::Socket *socket);
 SW_API swoole::coroutine::Socket *php_swoole_get_socket(zval *zobject);
 #ifdef SW_USE_OPENSSL
