@@ -301,13 +301,18 @@ enum sw_mysql_server_status_flags
                 sw_mysql_int4store((T),def_temp); \
                 sw_mysql_int4store((T+4),def_temp2); } while (0)
 
+#define sw_mysql_doublestore(T,A) do { \
+                double def_temp = (double) A; \
+                memcpy(T, &def_temp, sizeof(double)); \
+                } while (0)
+
 #if defined(SW_DEBUG) && defined(SW_LOG_TRACE_OPEN)
 #define swMysqlPacketDump(length, number, data, title) \
     if (SW_LOG_TRACE >= sw_logger()->get_level() && (SW_TRACE_MYSQL_CLIENT & SwooleG.trace_flags)) \
     { \
-        swDebug("+----------+------------+-------------------------------------------------------+"); \
-        swDebug("| P#%-6u | L%-9u | %-10u %42s |", number, SW_MYSQL_PACKET_HEADER_SIZE + length, length, title); \
-        swHexDump(data, length); \
+        swoole_debug("+----------+------------+-------------------------------------------------------+"); \
+        swoole_debug("| P#%-6u | L%-9u | %-10u %42s |", number, SW_MYSQL_PACKET_HEADER_SIZE + length, length, title); \
+        swoole_hex_dump(data, length); \
     }
 #else
 #define swMysqlPacketDump(length, number, data, title)
@@ -481,7 +486,7 @@ public:
     inline bool more_results_exists()
     {
         bool b = !!(status & SW_MYSQL_SERVER_MORE_RESULTS_EXISTS);
-        swTraceLog(SW_TRACE_MYSQL_CLIENT, "More results exist = %u", b);
+        swoole_trace_log(SW_TRACE_MYSQL_CLIENT, "More results exist = %u", b);
         return b;
     }
 };
@@ -684,7 +689,7 @@ public:
     {
         swMysqlPacketDump(header.length, header.number, data, "Protocol::LengthCodedBinary");
         bytes_length = read_lcb(data + SW_MYSQL_PACKET_HEADER_SIZE, &length, &nul);
-        swTraceLog(SW_TRACE_MYSQL_CLIENT, "binary_length=%" PRIu64 ", nul=%u", header.length, nul);
+        swoole_trace_log(SW_TRACE_MYSQL_CLIENT, "binary_length=%u, nul=%u", header.length, nul);
     }
     bool is_vaild()
     {
@@ -793,10 +798,10 @@ public:
     {
         body = *pp + read_lcb(*pp, &length, &nul);
         *pp = body + length;
-        swTraceLog(
+        swoole_trace_log(
             SW_TRACE_MYSQL_CLIENT,
             "text[%" PRIu64 "]: %.*s%s",
-            length, SW_MIN(64, length), body,
+            length, (int) SW_MIN(64, length), body,
             nul ? "null" : ((length > 64 /*|| length > readable_length*/) ? "..." : "")
         );
     }
@@ -965,7 +970,7 @@ public:
         data += 1;
         // warning_count (2) -- number of warnings
         warning_count = sw_mysql_uint2korr2korr(data);
-        swTraceLog(
+        swoole_trace_log(
             SW_TRACE_MYSQL_CLIENT, "statement_id=%u, field_count=%u, param_count=%u, warning_count=%u",
             id, field_count, param_count, warning_count
         );
@@ -984,7 +989,7 @@ public:
     {
         map = new char[size];
         memcpy(map, p, size);
-        swTraceLog(SW_TRACE_MYSQL_CLIENT, "null_count=%u", size);
+        swoole_trace_log(SW_TRACE_MYSQL_CLIENT, "null_count=%u", size);
     }
     inline bool is_null(size_t i)
     {
