@@ -41,7 +41,7 @@ static sw_inline ProcessObject *php_swoole_process_fetch_object(zend_object *obj
     return (ProcessObject *) ((char *) obj - swoole_process_handlers.offset);
 }
 
-static sw_inline Worker *php_swoole_process_get_worker(zval *zobject) {
+Worker *php_swoole_process_get_worker(zval *zobject) {
     return php_swoole_process_fetch_object(Z_OBJ_P(zobject))->worker;
 }
 
@@ -258,7 +258,7 @@ static const zend_function_entry swoole_process_methods[] =
 
 void php_swoole_process_minit(int module_number) {
     SW_INIT_CLASS_ENTRY(swoole_process, "Swoole\\Process", "swoole_process", nullptr, swoole_process_methods);
-    SW_SET_CLASS_SERIALIZABLE(swoole_process, zend_class_serialize_deny, zend_class_unserialize_deny);
+    SW_SET_CLASS_NOT_SERIALIZABLE(swoole_process);
     SW_SET_CLASS_CLONEABLE(swoole_process, sw_zend_class_clone_deny);
     SW_SET_CLASS_UNSET_PROPERTY_HANDLER(swoole_process, sw_zend_class_unset_property_deny);
     SW_SET_CLASS_CUSTOM_OBJECT(
@@ -506,7 +506,7 @@ static PHP_METHOD(swoole_process, kill) {
     int ret = swoole_kill((int) pid, (int) sig);
     if (ret < 0) {
         if (!(sig == 0 && errno == ESRCH)) {
-            php_swoole_sys_error(E_WARNING, "swKill(%d, %d) failed", (int) pid, (int) sig);
+            php_swoole_sys_error(E_WARNING, "kill(%d, %d) failed", (int) pid, (int) sig);
         }
         RETURN_FALSE;
     }
@@ -534,7 +534,7 @@ static PHP_METHOD(swoole_process, signal) {
         RETURN_FALSE;
     }
 
-    swSignalHandler handler = swSignal_get_handler(signo);
+    swSignalHandler handler = swoole_signal_get_handler(signo);
     if (handler && handler != php_swoole_onSignal) {
         php_swoole_fatal_error(
             E_WARNING, "signal [" ZEND_LONG_FMT "] processor has been registered by the system", signo);
@@ -544,7 +544,7 @@ static PHP_METHOD(swoole_process, signal) {
     if (zcallback == nullptr) {
         fci_cache = signal_fci_caches[signo];
         if (fci_cache) {
-            swSignal_set(signo, nullptr);
+            swoole_signal_set(signo, nullptr);
             signal_fci_caches[signo] = nullptr;
             swoole_event_defer(sw_zend_fci_cache_free, fci_cache);
             SwooleTG.signal_listener_num--;
@@ -576,7 +576,7 @@ static PHP_METHOD(swoole_process, signal) {
             SwooleTG.signal_listener_num++;
         }
         signal_fci_caches[signo] = fci_cache;
-        swSignal_set(signo, handler);
+        swoole_signal_set(signo, handler);
         RETURN_TRUE;
     }
 
@@ -601,7 +601,7 @@ static PHP_METHOD(swoole_process, signal) {
     // use user settings
     SwooleG.use_signalfd = SwooleG.enable_signalfd;
 
-    swSignal_set(signo, handler);
+    swoole_signal_set(signo, handler);
 
     RETURN_TRUE;
 }
@@ -998,7 +998,7 @@ static PHP_METHOD(swoole_process, daemon) {
                 int new_fd = php_swoole_convert_to_fd(elem);
                 if (new_fd >= 0) {
                     if (dup2(new_fd, fd) < 0) {
-                        swSysWarn("dup2(%d, %d) failed", new_fd, fd);
+                        swoole_sys_warning("dup2(%d, %d) failed", new_fd, fd);
                     }
                 }
             }
