@@ -40,6 +40,8 @@ struct ProcessPoolObject {
     zend_object std;
 };
 
+static void pool_signal_handler(int sig);
+
 static sw_inline ProcessPoolObject *php_swoole_process_pool_fetch_object(zend_object *obj) {
     return (ProcessPoolObject *) ((char *) obj - swoole_process_pool_handlers.offset);
 }
@@ -125,8 +127,10 @@ static PHP_METHOD(swoole_process_pool, set);
 static PHP_METHOD(swoole_process_pool, on);
 static PHP_METHOD(swoole_process_pool, listen);
 static PHP_METHOD(swoole_process_pool, write);
+static PHP_METHOD(swoole_process_pool, detach);
 static PHP_METHOD(swoole_process_pool, getProcess);
 static PHP_METHOD(swoole_process_pool, start);
+static PHP_METHOD(swoole_process_pool, stop);
 static PHP_METHOD(swoole_process_pool, shutdown);
 SW_EXTERN_C_END
 
@@ -174,7 +178,9 @@ static const zend_function_entry swoole_process_pool_methods[] =
     PHP_ME(swoole_process_pool, getProcess, arginfo_swoole_process_pool_getProcess, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_process_pool, listen, arginfo_swoole_process_pool_listen, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_process_pool, write, arginfo_swoole_process_pool_write, ZEND_ACC_PUBLIC)
+    PHP_ME(swoole_process_pool, detach, arginfo_swoole_process_pool_void, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_process_pool, start, arginfo_swoole_process_pool_void, ZEND_ACC_PUBLIC)
+    PHP_ME(swoole_process_pool, stop, arginfo_swoole_process_pool_void, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_process_pool, shutdown, arginfo_swoole_process_pool_void, ZEND_ACC_PUBLIC)
     PHP_FE_END
 };
@@ -183,7 +189,7 @@ static const zend_function_entry swoole_process_pool_methods[] =
 void php_swoole_process_pool_minit(int module_number) {
     SW_INIT_CLASS_ENTRY(
         swoole_process_pool, "Swoole\\Process\\Pool", "swoole_process_pool", nullptr, swoole_process_pool_methods);
-    SW_SET_CLASS_SERIALIZABLE(swoole_process_pool, zend_class_serialize_deny, zend_class_unserialize_deny);
+    SW_SET_CLASS_NOT_SERIALIZABLE(swoole_process_pool);
     SW_SET_CLASS_CLONEABLE(swoole_process_pool, sw_zend_class_clone_deny);
     SW_SET_CLASS_UNSET_PROPERTY_HANDLER(swoole_process_pool, sw_zend_class_unset_property_deny);
     SW_SET_CLASS_CUSTOM_OBJECT(swoole_process_pool,
@@ -203,7 +209,6 @@ static void pool_onWorkerStart(ProcessPool *pool, int worker_id) {
     php_swoole_process_clean();
     SwooleG.process_id = worker_id;
     current_pool = pool;
-
     // main function
     if (!pp->onWorkerStart) {
         return;
@@ -212,6 +217,9 @@ static void pool_onWorkerStart(ProcessPool *pool, int worker_id) {
     if (pp->enable_coroutine && php_swoole_reactor_init() < 0) {
         return;
     }
+    if (!pp->enable_coroutine && pp->onMessage) {
+        swoole_signal_set(SIGTERM, pool_signal_handler);
+    }
     zval args[2];
     args[0] = *zobject;
     ZVAL_LONG(&args[1], worker_id);
@@ -257,6 +265,9 @@ static void pool_onWorkerStop(ProcessPool *pool, int worker_id) {
 }
 
 static void pool_signal_handler(int sig) {
+    if (!current_pool) {
+        return;
+    }
     switch (sig) {
     case SIGTERM:
         current_pool->running = false;
@@ -266,6 +277,9 @@ static void pool_signal_handler(int sig) {
         current_pool->reloading = true;
         current_pool->reload_init = false;
         break;
+    case SIGIO:
+        current_pool->read_message = true;
+        break;
     default:
         break;
     }
@@ -320,10 +334,7 @@ static PHP_METHOD(swoole_process_pool, __construct) {
         pool->main_loop = nullptr;
     } else {
         if (ipc_type > 0) {
-            if (pool->set_protocol(0, SW_INPUT_BUFFER_SIZE) < 0) {
-                zend_throw_exception_ex(swoole_exception_ce, errno, "failed to create process pool");
-                RETURN_FALSE;
-            }
+            pool->set_protocol(0, SW_INPUT_BUFFER_SIZE);
         }
     }
 
@@ -346,9 +357,18 @@ static PHP_METHOD(swoole_process_pool, set) {
 
     ProcessPoolProperty *pp = php_swoole_process_pool_get_and_check_pp(ZEND_THIS);
 
+    php_swoole_set_global_option(vht);
+    php_swoole_set_coroutine_option(vht);
+    php_swoole_set_aio_option(vht);
+
     if (php_swoole_array_get_value(vht, "enable_coroutine", ztmp)) {
         pp->enable_coroutine = zval_is_true(ztmp);
     }
+
+    ProcessPool *pool = php_swoole_process_pool_get_and_check_pool(ZEND_THIS);
+    if (pp->enable_coroutine) {
+        pool->main_loop = nullptr;
+    }
 }
 
 static PHP_METHOD(swoole_process_pool, on) {
@@ -494,9 +514,10 @@ static PHP_METHOD(swoole_process_pool, start) {
 
     std::unordered_map<int, swSignalHandler> ori_handlers;
 
-    ori_handlers[SIGTERM] = swSignal_set(SIGTERM, pool_signal_handler);
-    ori_handlers[SIGUSR1] = swSignal_set(SIGUSR1, pool_signal_handler);
-    ori_handlers[SIGUSR2] = swSignal_set(SIGUSR2, pool_signal_handler);
+    ori_handlers[SIGTERM] = swoole_signal_set(SIGTERM, pool_signal_handler);
+    ori_handlers[SIGUSR1] = swoole_signal_set(SIGUSR1, pool_signal_handler);
+    ori_handlers[SIGUSR2] = swoole_signal_set(SIGUSR2, pool_signal_handler);
+    ori_handlers[SIGIO] = swoole_signal_set(SIGIO, pool_signal_handler);
 
     if (pool->ipc_mode == SW_IPC_NONE || pp->enable_coroutine) {
         if (pp->onWorkerStart == nullptr) {
@@ -536,11 +557,16 @@ static PHP_METHOD(swoole_process_pool, start) {
     current_pool = nullptr;
 
     for (auto iter = ori_handlers.begin(); iter != ori_handlers.end(); iter++) {
-        swSignal_set(iter->first, iter->second);
+        swoole_signal_set(iter->first, iter->second);
     }
 }
 
-extern void php_swoole_process_set_worker(zval *zobject, Worker *worker);
+static PHP_METHOD(swoole_process_pool, detach) {
+    if (current_pool == nullptr) {
+        RETURN_FALSE;
+    }
+    RETURN_BOOL(current_pool->detach());
+}
 
 static PHP_METHOD(swoole_process_pool, getProcess) {
     long worker_id = -1;
@@ -595,11 +621,23 @@ static PHP_METHOD(swoole_process_pool, getProcess) {
         zend::Process *proc = new zend::Process(zend::PIPE_TYPE_STREAM, pp->enable_coroutine);
         worker->ptr2 = proc;
         (void) add_index_zval(zworkers, worker_id, zprocess);
+    } else {
+        auto _worker = php_swoole_process_get_worker(zprocess);
+        if (_worker->pid != current_pool->workers[worker_id].pid) {
+            _worker->pid = current_pool->workers[worker_id].pid;
+            zend_update_property_long(swoole_process_ce, SW_Z8_OBJ_P(zprocess), ZEND_STRL("pid"), _worker->pid);
+        }
     }
 
     RETURN_ZVAL(zprocess, 1, 0);
 }
 
+static PHP_METHOD(swoole_process_pool, stop) {
+    if (current_pool) {
+        current_pool->running = false;
+    }
+}
+
 static PHP_METHOD(swoole_process_pool, shutdown) {
     zval *retval =
         sw_zend_read_property_ex(swoole_process_pool_ce, ZEND_THIS, SW_ZSTR_KNOWN(SW_ZEND_STR_MASTER_PID), 0);
