@@ -18,38 +18,39 @@
 
 using namespace swoole;
 
-struct server_port_event {
+struct ServerPortEvent {
     enum php_swoole_server_port_callback_type type;
     std::string name;
-    server_port_event(enum php_swoole_server_port_callback_type type, std::string &&name) : type(type), name(name) {}
+    ServerPortEvent(enum php_swoole_server_port_callback_type type, std::string &&name) : type(type), name(name) {}
 };
 
 // clang-format off
-static std::unordered_map<std::string, server_port_event> server_port_event_map({
-    { "connect",     server_port_event(SW_SERVER_CB_onConnect,     "Connect") },
-    { "receive",     server_port_event(SW_SERVER_CB_onReceive,     "Receive") },
-    { "close",       server_port_event(SW_SERVER_CB_onClose,       "Close") },
-    { "packet",      server_port_event(SW_SERVER_CB_onPacket,      "Packet") },
-    { "bufferfull",  server_port_event(SW_SERVER_CB_onBufferFull,  "BufferFull") },
-    { "bufferempty", server_port_event(SW_SERVER_CB_onBufferEmpty, "BufferEmpty") },
-    { "request",     server_port_event(SW_SERVER_CB_onRequest,     "Request") },
-    { "handshake",   server_port_event(SW_SERVER_CB_onHandShake,   "Handshake") },
-    { "open",        server_port_event(SW_SERVER_CB_onOpen,        "Open") },
-    { "message",     server_port_event(SW_SERVER_CB_onMessage,     "Message") },
+static std::unordered_map<std::string, ServerPortEvent> server_port_event_map({
+    { "connect",     ServerPortEvent(SW_SERVER_CB_onConnect,     "Connect") },
+    { "receive",     ServerPortEvent(SW_SERVER_CB_onReceive,     "Receive") },
+    { "close",       ServerPortEvent(SW_SERVER_CB_onClose,       "Close") },
+    { "packet",      ServerPortEvent(SW_SERVER_CB_onPacket,      "Packet") },
+    { "bufferfull",  ServerPortEvent(SW_SERVER_CB_onBufferFull,  "BufferFull") },
+    { "bufferempty", ServerPortEvent(SW_SERVER_CB_onBufferEmpty, "BufferEmpty") },
+    { "request",     ServerPortEvent(SW_SERVER_CB_onRequest,     "Request") },
+    { "handshake",   ServerPortEvent(SW_SERVER_CB_onHandShake,   "Handshake") },
+    { "open",        ServerPortEvent(SW_SERVER_CB_onOpen,        "Open") },
+    { "message",     ServerPortEvent(SW_SERVER_CB_onMessage,     "Message") },
+    { "disconnect",  ServerPortEvent(SW_SERVER_CB_onDisconnect,  "Disconnect") },
 });
 // clang-format on
 
 zend_class_entry *swoole_server_port_ce;
 static zend_object_handlers swoole_server_port_handlers;
 
-struct server_port_t {
+struct ServerPortObject {
     ListenPort *port;
     ServerPortProperty property;
     zend_object std;
 };
 
-static sw_inline server_port_t *php_swoole_server_port_fetch_object(zend_object *obj) {
-    return (server_port_t *) ((char *) obj - swoole_server_port_handlers.offset);
+static sw_inline ServerPortObject *php_swoole_server_port_fetch_object(zend_object *obj) {
+    return (ServerPortObject *) ((char *) obj - swoole_server_port_handlers.offset);
 }
 
 static sw_inline ListenPort *php_swoole_server_port_get_ptr(zval *zobject) {
@@ -59,7 +60,7 @@ static sw_inline ListenPort *php_swoole_server_port_get_ptr(zval *zobject) {
 ListenPort *php_swoole_server_port_get_and_check_ptr(zval *zobject) {
     ListenPort *port = php_swoole_server_port_get_ptr(zobject);
     if (UNEXPECTED(!port)) {
-        php_swoole_fatal_error(E_ERROR, "Invaild instance of %s", SW_Z_OBJCE_NAME_VAL_P(zobject));
+        php_swoole_fatal_error(E_ERROR, "Invalid instance of %s", SW_Z_OBJCE_NAME_VAL_P(zobject));
     }
     return port;
 }
@@ -75,14 +76,14 @@ ServerPortProperty *php_swoole_server_port_get_property(zval *zobject) {
 static ServerPortProperty *php_swoole_server_port_get_and_check_property(zval *zobject) {
     ServerPortProperty *property = php_swoole_server_port_get_property(zobject);
     if (UNEXPECTED(!property->serv)) {
-        php_swoole_fatal_error(E_ERROR, "Invaild instance of %s", SW_Z_OBJCE_NAME_VAL_P(zobject));
+        php_swoole_fatal_error(E_ERROR, "Invalid instance of %s", SW_Z_OBJCE_NAME_VAL_P(zobject));
     }
     return property;
 }
 
 // Dereference from server object
 void php_swoole_server_port_deref(zend_object *object) {
-    server_port_t *server_port = php_swoole_server_port_fetch_object(object);
+    ServerPortObject *server_port = php_swoole_server_port_fetch_object(object);
     ServerPortProperty *property = &server_port->property;
     if (property->serv) {
         for (int j = 0; j < PHP_SWOOLE_SERVER_PORT_CALLBACK_NUM; j++) {
@@ -111,7 +112,7 @@ static void php_swoole_server_port_free_object(zend_object *object) {
 }
 
 static zend_object *php_swoole_server_port_create_object(zend_class_entry *ce) {
-    server_port_t *server_port = (server_port_t *) zend_object_alloc(sizeof(server_port_t), ce);
+    ServerPortObject *server_port = (ServerPortObject *) zend_object_alloc(sizeof(ServerPortObject), ce);
     zend_object_std_init(&server_port->std, ce);
     object_properties_init(&server_port->std, ce);
     server_port->std.handlers = &swoole_server_port_handlers;
@@ -165,13 +166,13 @@ const zend_function_entry swoole_server_port_methods[] =
 void php_swoole_server_port_minit(int module_number) {
     SW_INIT_CLASS_ENTRY(
         swoole_server_port, "Swoole\\Server\\Port", "swoole_server_port", nullptr, swoole_server_port_methods);
-    SW_SET_CLASS_SERIALIZABLE(swoole_server_port, zend_class_serialize_deny, zend_class_unserialize_deny);
+    SW_SET_CLASS_NOT_SERIALIZABLE(swoole_server_port);
     SW_SET_CLASS_CLONEABLE(swoole_server_port, sw_zend_class_clone_deny);
     SW_SET_CLASS_UNSET_PROPERTY_HANDLER(swoole_server_port, sw_zend_class_unset_property_deny);
     SW_SET_CLASS_CUSTOM_OBJECT(swoole_server_port,
                                php_swoole_server_port_create_object,
                                php_swoole_server_port_free_object,
-                               server_port_t,
+                               ServerPortObject,
                                std);
 
     zend_declare_property_null(swoole_server_port_ce, ZEND_STRL("onConnect"), ZEND_ACC_PRIVATE);
@@ -184,6 +185,7 @@ void php_swoole_server_port_minit(int module_number) {
     zend_declare_property_null(swoole_server_port_ce, ZEND_STRL("onHandShake"), ZEND_ACC_PRIVATE);
     zend_declare_property_null(swoole_server_port_ce, ZEND_STRL("onOpen"), ZEND_ACC_PRIVATE);
     zend_declare_property_null(swoole_server_port_ce, ZEND_STRL("onMessage"), ZEND_ACC_PRIVATE);
+    zend_declare_property_null(swoole_server_port_ce, ZEND_STRL("onDisconnect"), ZEND_ACC_PRIVATE);
 
     zend_declare_property_null(swoole_server_port_ce, ZEND_STRL("host"), ZEND_ACC_PUBLIC);
     zend_declare_property_long(swoole_server_port_ce, ZEND_STRL("port"), 0, ZEND_ACC_PUBLIC);
@@ -197,7 +199,10 @@ void php_swoole_server_port_minit(int module_number) {
 /**
  * [Master-Process]
  */
-static ssize_t php_swoole_server_length_func(Protocol *protocol, network::Socket *conn, const char *data, uint32_t length) {
+static ssize_t php_swoole_server_length_func(Protocol *protocol,
+                                             network::Socket *conn,
+                                             const char *data,
+                                             uint32_t length) {
     Server *serv = (Server *) protocol->private_data_2;
     serv->lock();
 
@@ -307,6 +312,11 @@ static PHP_METHOD(swoole_server_port, set) {
             port->kernel_socket_send_buffer_size = INT_MAX;
         }
     }
+    // heartbeat idle time
+    if (php_swoole_array_get_value(vht, "heartbeat_idle_time", ztmp)) {
+        zend_long v = zval_get_long(ztmp);
+        port->heartbeat_idle_time = SW_MAX(0, SW_MIN(v, UINT16_MAX));
+    }
     if (php_swoole_array_get_value(vht, "buffer_high_watermark", ztmp)) {
         zend_long v = zval_get_long(ztmp);
         port->buffer_high_watermark = SW_MAX(0, SW_MIN(v, UINT32_MAX));
@@ -431,7 +441,7 @@ static PHP_METHOD(swoole_server_port, set) {
         port->protocol.package_length_type = str_v.val()[0];
         port->protocol.package_length_size = swoole_type_size(port->protocol.package_length_type);
         if (port->protocol.package_length_size == 0) {
-            php_swoole_fatal_error(E_ERROR, "unknow package_length_type, see pack(). Link: http://php.net/pack");
+            php_swoole_fatal_error(E_ERROR, "unknown package_length_type, see pack(). Link: http://php.net/pack");
             RETURN_FALSE;
         }
     }
@@ -588,7 +598,8 @@ static PHP_METHOD(swoole_server_port, set) {
                     delete context;
                     RETURN_FALSE;
                 }
-            } ZEND_HASH_FOREACH_END();
+            }
+            ZEND_HASH_FOREACH_END();
         }
 
         if (!port->ssl_context->cert_file.empty() || port->sni_contexts.empty()) {
@@ -618,7 +629,7 @@ static PHP_METHOD(swoole_server_port, set) {
 
 static PHP_METHOD(swoole_server_port, on) {
     char *name = nullptr;
-    size_t len, i;
+    size_t len;
     zval *cb;
 
     ServerPortProperty *property = php_swoole_server_port_get_and_check_property(ZEND_THIS);
@@ -640,55 +651,40 @@ static PHP_METHOD(swoole_server_port, on) {
     }
     efree(func_name);
 
-    const char *callback_name[PHP_SWOOLE_SERVER_PORT_CALLBACK_NUM] = {
-        "Connect",
-        "Receive",
-        "Close",
-        "Packet",
-        "Request",
-        "HandShake",
-        "Open",
-        "Message",
-        "BufferFull",
-        "BufferEmpty",
-    };
-
-    char property_name[128];
-    int l_property_name = 0;
-    memcpy(property_name, "on", 2);
-
-    for (i = 0; i < PHP_SWOOLE_SERVER_PORT_CALLBACK_NUM; i++) {
-        if (!swoole_strcaseeq(name, len, callback_name[i], strlen(callback_name[i]))) {
+    bool found = false;
+    for (auto i = server_port_event_map.begin(); i != server_port_event_map.end(); i++) {
+        if (!swoole_strcaseeq(name, len, i->first.c_str(), i->first.length())) {
             continue;
         }
 
-        memcpy(property_name + 2, callback_name[i], len);
-        l_property_name = len + 2;
-        property_name[l_property_name] = '\0';
-        zend_update_property(swoole_server_port_ce, SW_Z8_OBJ_P(ZEND_THIS), property_name, l_property_name, cb);
-        property->callbacks[i] =
-            sw_zend_read_property(swoole_server_port_ce, ZEND_THIS, property_name, l_property_name, 0);
-        sw_copy_to_stack(property->callbacks[i], property->_callbacks[i]);
-        if (property->caches[i]) {
-            efree(property->caches[i]);
+        found = true;
+        int index = i->second.type;
+        std::string property_name = std::string("on") + i->second.name;
+        zend_update_property(
+            swoole_server_port_ce, SW_Z8_OBJ_P(ZEND_THIS), property_name.c_str(), property_name.length(), cb);
+        property->callbacks[index] =
+            sw_zend_read_property(swoole_server_port_ce, ZEND_THIS, property_name.c_str(), property_name.length(), 0);
+        sw_copy_to_stack(property->callbacks[index], property->_callbacks[index]);
+        if (property->caches[index]) {
+            efree(property->caches[index]);
         }
-        property->caches[i] = fci_cache;
+        property->caches[index] = fci_cache;
 
-        if (i == SW_SERVER_CB_onConnect && !serv->onConnect) {
+        if (index == SW_SERVER_CB_onConnect && !serv->onConnect) {
             serv->onConnect = php_swoole_server_onConnect;
-        } else if (i == SW_SERVER_CB_onPacket && !serv->onPacket) {
+        } else if (index == SW_SERVER_CB_onPacket && !serv->onPacket) {
             serv->onPacket = php_swoole_server_onPacket;
-        } else if (i == SW_SERVER_CB_onClose && !serv->onClose) {
+        } else if (index == SW_SERVER_CB_onClose && !serv->onClose) {
             serv->onClose = php_swoole_server_onClose;
-        } else if (i == SW_SERVER_CB_onBufferFull && !serv->onBufferFull) {
+        } else if (index == SW_SERVER_CB_onBufferFull && !serv->onBufferFull) {
             serv->onBufferFull = php_swoole_server_onBufferFull;
-        } else if (i == SW_SERVER_CB_onBufferEmpty && !serv->onBufferEmpty) {
+        } else if (index == SW_SERVER_CB_onBufferEmpty && !serv->onBufferEmpty) {
             serv->onBufferEmpty = php_swoole_server_onBufferEmpty;
         }
         break;
     }
 
-    if (l_property_name == 0) {
+    if (!found) {
         php_swoole_error(E_WARNING, "unknown event types[%s]", name);
         efree(fci_cache);
         RETURN_FALSE;
