@@ -72,9 +72,6 @@ static inline void php_swoole_table_get_field_value(
 static zend_class_entry *swoole_table_ce;
 static zend_object_handlers swoole_table_handlers;
 
-static zend_class_entry *swoole_table_row_ce;
-static zend_object_handlers swoole_table_row_handlers;
-
 struct TableObject {
     Table *ptr;
     zend_object std;
@@ -124,43 +121,6 @@ static inline zend_object *php_swoole_table_create_object(zend_class_entry *ce)
     return &table->std;
 }
 
-struct TableRowObject {
-    Table *ptr;
-    zend_object std;
-};
-
-static inline TableRowObject *php_swoole_table_row_fetch_object(zend_object *obj) {
-    return (TableRowObject *) ((char *) obj - swoole_table_row_handlers.offset);
-}
-
-static inline Table *php_swoole_table_row_get_ptr(zval *zobject) {
-    return php_swoole_table_row_fetch_object(Z_OBJ_P(zobject))->ptr;
-}
-
-static inline Table *php_swoole_table_row_get_and_check_ptr(zval *zobject) {
-    Table *table_row = php_swoole_table_row_get_ptr(zobject);
-    if (!table_row) {
-        php_swoole_fatal_error(E_ERROR, "you can only get Table\\Row from Table");
-    }
-    return table_row;
-}
-
-static inline void php_swoole_table_row_set_ptr(zval *zobject, Table *ptr) {
-    php_swoole_table_row_fetch_object(Z_OBJ_P(zobject))->ptr = ptr;
-}
-
-static inline void php_swoole_table_row_free_object(zend_object *object) {
-    zend_object_std_dtor(object);
-}
-
-static inline zend_object *php_swoole_table_row_create_object(zend_class_entry *ce) {
-    TableRowObject *table_row = (TableRowObject *) zend_object_alloc(sizeof(TableRowObject), ce);
-    zend_object_std_init(&table_row->std, ce);
-    object_properties_init(&table_row->std, ce);
-    table_row->std.handlers = &swoole_table_row_handlers;
-    return &table_row->std;
-}
-
 // clang-format off
 ZEND_BEGIN_ARG_INFO_EX(arginfo_swoole_table_void, 0, 0, 0)
 ZEND_END_ARG_INFO()
@@ -190,23 +150,6 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_swoole_table_exists, 0, 0, 1)
     ZEND_ARG_INFO(0, key)
 ZEND_END_ARG_INFO()
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_swoole_table_offsetExists, 0, 0, 1)
-    ZEND_ARG_INFO(0, offset)
-ZEND_END_ARG_INFO()
-
-ZEND_BEGIN_ARG_INFO_EX(arginfo_swoole_table_offsetGet, 0, 0, 1)
-    ZEND_ARG_INFO(0, offset)
-ZEND_END_ARG_INFO()
-
-ZEND_BEGIN_ARG_INFO_EX(arginfo_swoole_table_offsetSet, 0, 0, 2)
-    ZEND_ARG_INFO(0, offset)
-    ZEND_ARG_INFO(0, value)
-ZEND_END_ARG_INFO()
-
-ZEND_BEGIN_ARG_INFO_EX(arginfo_swoole_table_offsetUnset, 0, 0, 1)
-    ZEND_ARG_INFO(0, offset)
-ZEND_END_ARG_INFO()
-
 ZEND_BEGIN_ARG_INFO_EX(arginfo_swoole_table_del, 0, 0, 1)
     ZEND_ARG_INFO(0, key)
 ZEND_END_ARG_INFO()
@@ -238,10 +181,6 @@ static PHP_METHOD(swoole_table, count);
 static PHP_METHOD(swoole_table, destroy);
 static PHP_METHOD(swoole_table, getSize);
 static PHP_METHOD(swoole_table, getMemorySize);
-static PHP_METHOD(swoole_table, offsetExists);
-static PHP_METHOD(swoole_table, offsetGet);
-static PHP_METHOD(swoole_table, offsetSet);
-static PHP_METHOD(swoole_table, offsetUnset);
 
 static PHP_METHOD(swoole_table, rewind);
 static PHP_METHOD(swoole_table, next);
@@ -249,11 +188,6 @@ static PHP_METHOD(swoole_table, current);
 static PHP_METHOD(swoole_table, key);
 static PHP_METHOD(swoole_table, valid);
 
-static PHP_METHOD(swoole_table_row, offsetExists);
-static PHP_METHOD(swoole_table_row, offsetGet);
-static PHP_METHOD(swoole_table_row, offsetSet);
-static PHP_METHOD(swoole_table_row, offsetUnset);
-static PHP_METHOD(swoole_table_row, __destruct);
 SW_EXTERN_C_END
 
 // clang-format off
@@ -274,39 +208,24 @@ static const zend_function_entry swoole_table_methods[] =
     PHP_ME(swoole_table, decr,        arginfo_swoole_table_decr, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_table, getSize,    arginfo_swoole_table_void, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_table, getMemorySize,    arginfo_swoole_table_void, ZEND_ACC_PUBLIC)
-    // implement ArrayAccess
-    PHP_ME(swoole_table, offsetExists,     arginfo_swoole_table_offsetExists, ZEND_ACC_PUBLIC)
-    PHP_ME(swoole_table, offsetGet,        arginfo_swoole_table_offsetGet, ZEND_ACC_PUBLIC)
-    PHP_ME(swoole_table, offsetSet,        arginfo_swoole_table_offsetSet, ZEND_ACC_PUBLIC)
-    PHP_ME(swoole_table, offsetUnset,      arginfo_swoole_table_offsetUnset, ZEND_ACC_PUBLIC)
     // implement Iterator
     PHP_ME(swoole_table, rewind,      arginfo_swoole_table_void, ZEND_ACC_PUBLIC)
+    PHP_ME(swoole_table, valid,       arginfo_swoole_table_void, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_table, next,        arginfo_swoole_table_void, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_table, current,     arginfo_swoole_table_void, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_table, key,         arginfo_swoole_table_void, ZEND_ACC_PUBLIC)
-    PHP_ME(swoole_table, valid,       arginfo_swoole_table_void, ZEND_ACC_PUBLIC)
-    PHP_FE_END
-};
-
-static const zend_function_entry swoole_table_row_methods[] =
-{
-    PHP_ME(swoole_table_row, offsetExists,     arginfo_swoole_table_offsetExists, ZEND_ACC_PUBLIC)
-    PHP_ME(swoole_table_row, offsetGet,        arginfo_swoole_table_offsetGet, ZEND_ACC_PUBLIC)
-    PHP_ME(swoole_table_row, offsetSet,        arginfo_swoole_table_offsetSet, ZEND_ACC_PUBLIC)
-    PHP_ME(swoole_table_row, offsetUnset,      arginfo_swoole_table_offsetUnset, ZEND_ACC_PUBLIC)
-    PHP_ME(swoole_table_row, __destruct,       arginfo_swoole_table_void, ZEND_ACC_PUBLIC)
     PHP_FE_END
 };
 // clang-format on
 
 void php_swoole_table_minit(int module_number) {
     SW_INIT_CLASS_ENTRY(swoole_table, "Swoole\\Table", "swoole_table", nullptr, swoole_table_methods);
-    SW_SET_CLASS_SERIALIZABLE(swoole_table, zend_class_serialize_deny, zend_class_unserialize_deny);
+    SW_SET_CLASS_NOT_SERIALIZABLE(swoole_table);
     SW_SET_CLASS_CLONEABLE(swoole_table, sw_zend_class_clone_deny);
     SW_SET_CLASS_UNSET_PROPERTY_HANDLER(swoole_table, sw_zend_class_unset_property_deny);
     SW_SET_CLASS_CUSTOM_OBJECT(
         swoole_table, php_swoole_table_create_object, php_swoole_table_free_object, TableObject, std);
-    zend_class_implements(swoole_table_ce, 2, zend_ce_iterator, zend_ce_arrayaccess);
+    zend_class_implements(swoole_table_ce, 1, zend_ce_iterator);
 #ifdef SW_HAVE_COUNTABLE
     zend_class_implements(swoole_table_ce, 1, zend_ce_countable);
 #endif
@@ -317,17 +236,6 @@ void php_swoole_table_minit(int module_number) {
     zend_declare_class_constant_long(swoole_table_ce, ZEND_STRL("TYPE_INT"), TableColumn::TYPE_INT);
     zend_declare_class_constant_long(swoole_table_ce, ZEND_STRL("TYPE_STRING"), TableColumn::TYPE_STRING);
     zend_declare_class_constant_long(swoole_table_ce, ZEND_STRL("TYPE_FLOAT"), TableColumn::TYPE_FLOAT);
-
-    SW_INIT_CLASS_ENTRY(swoole_table_row, "Swoole\\Table\\Row", "swoole_table_row", nullptr, swoole_table_row_methods);
-    SW_SET_CLASS_SERIALIZABLE(swoole_table_row, zend_class_serialize_deny, zend_class_unserialize_deny);
-    SW_SET_CLASS_CLONEABLE(swoole_table_row, sw_zend_class_clone_deny);
-    SW_SET_CLASS_UNSET_PROPERTY_HANDLER(swoole_table_row, sw_zend_class_unset_property_deny);
-    SW_SET_CLASS_CUSTOM_OBJECT(
-        swoole_table_row, php_swoole_table_row_create_object, php_swoole_table_row_free_object, TableRowObject, std);
-    zend_class_implements(swoole_table_row_ce, 1, zend_ce_arrayaccess);
-
-    zend_declare_property_null(swoole_table_row_ce, ZEND_STRL("key"), ZEND_ACC_PUBLIC);
-    zend_declare_property_null(swoole_table_row_ce, ZEND_STRL("value"), ZEND_ACC_PUBLIC);
 }
 
 PHP_METHOD(swoole_table, __construct) {
@@ -482,10 +390,6 @@ static PHP_METHOD(swoole_table, set) {
     RETURN_TRUE;
 }
 
-static PHP_METHOD(swoole_table, offsetSet) {
-    ZEND_MN(swoole_table_set)(INTERNAL_FUNCTION_PARAM_PASSTHRU);
-}
-
 static PHP_METHOD(swoole_table, incr) {
     Table *table = php_swoole_table_get_and_check_ptr2(ZEND_THIS);
     char *key;
@@ -631,34 +535,6 @@ static PHP_METHOD(swoole_table, get) {
     _rowlock->unlock();
 }
 
-static PHP_METHOD(swoole_table, offsetGet) {
-    Table *table = php_swoole_table_get_and_check_ptr2(ZEND_THIS);
-    char *key;
-    size_t keylen;
-    char *field = nullptr;
-    size_t field_len = 0;
-
-    if (zend_parse_parameters(ZEND_NUM_ARGS(), "s|s", &key, &keylen, &field, &field_len) == FAILURE) {
-        RETURN_FALSE;
-    }
-
-    zval value;
-    TableRow *_rowlock = nullptr;
-    TableRow *row = table->get(key, keylen, &_rowlock);
-    if (!row) {
-        array_init(&value);
-    } else {
-        php_swoole_table_row2array(table, row, &value);
-    }
-    _rowlock->unlock();
-
-    object_init_ex(return_value, swoole_table_row_ce);
-    zend_update_property(swoole_table_row_ce, SW_Z8_OBJ_P(return_value), ZEND_STRL("value"), &value);
-    zend_update_property_stringl(swoole_table_row_ce, SW_Z8_OBJ_P(return_value), ZEND_STRL("key"), key, keylen);
-    zval_ptr_dtor(&value);
-    php_swoole_table_row_set_ptr(return_value, table);
-}
-
 static PHP_METHOD(swoole_table, exists) {
     Table *table = php_swoole_table_get_and_check_ptr2(ZEND_THIS);
     char *key;
@@ -667,19 +543,7 @@ static PHP_METHOD(swoole_table, exists) {
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "s", &key, &keylen) == FAILURE) {
         RETURN_FALSE;
     }
-
-    TableRow *_rowlock = nullptr;
-    TableRow *row = table->get(key, keylen, &_rowlock);
-    _rowlock->unlock();
-    if (!row) {
-        RETURN_FALSE;
-    } else {
-        RETURN_TRUE;
-    }
-}
-
-static PHP_METHOD(swoole_table, offsetExists) {
-    ZEND_MN(swoole_table_exists)(INTERNAL_FUNCTION_PARAM_PASSTHRU);
+    RETURN_BOOL(table->exists(key, keylen));
 }
 
 static PHP_METHOD(swoole_table, del) {
@@ -694,21 +558,15 @@ static PHP_METHOD(swoole_table, del) {
     RETURN_BOOL(table->del(key, keylen));
 }
 
-static PHP_METHOD(swoole_table, offsetUnset) {
-    ZEND_MN(swoole_table_del)(INTERNAL_FUNCTION_PARAM_PASSTHRU);
-}
-
 static PHP_METHOD(swoole_table, count) {
 #define COUNT_NORMAL 0
 #define COUNT_RECURSIVE 1
-
     Table *table = php_swoole_table_get_ptr(ZEND_THIS);
     if (!table) {
         RETURN_LONG(0);
     }
 
     zend_long mode = COUNT_NORMAL;
-
     if (zend_parse_parameters(ZEND_NUM_ARGS(), "|l", &mode) == FAILURE) {
         RETURN_FALSE;
     }
@@ -722,7 +580,6 @@ static PHP_METHOD(swoole_table, count) {
 
 static PHP_METHOD(swoole_table, getMemorySize) {
     Table *table = php_swoole_table_get_ptr(ZEND_THIS);
-
     if (!table) {
         RETURN_LONG(0);
     } else {
@@ -732,7 +589,6 @@ static PHP_METHOD(swoole_table, getMemorySize) {
 
 static PHP_METHOD(swoole_table, getSize) {
     Table *table = php_swoole_table_get_ptr(ZEND_THIS);
-
     if (!table) {
         RETURN_LONG(0);
     } else {
@@ -746,126 +602,31 @@ static PHP_METHOD(swoole_table, rewind) {
     table->forward();
 }
 
+static PHP_METHOD(swoole_table, valid) {
+    Table *table = php_swoole_table_get_and_check_ptr2(ZEND_THIS);
+    auto key = table->current();
+    RETURN_BOOL(key->key_len != 0);
+}
+
 static PHP_METHOD(swoole_table, current) {
     Table *table = php_swoole_table_get_and_check_ptr2(ZEND_THIS);
-    TableRow *row = table->current();
-    if (row) {
-        row->lock();
-        php_swoole_table_row2array(table, row, return_value);
-        row->unlock();
-    } else {
+    auto row = table->current();
+    if (row->key_len == 0) {
         RETURN_NULL();
     }
+    php_swoole_table_row2array(table, row, return_value);
 }
 
 static PHP_METHOD(swoole_table, key) {
     Table *table = php_swoole_table_get_and_check_ptr2(ZEND_THIS);
-    TableRow *row = table->current();
-    if (row) {
-        row->lock();
-        RETVAL_STRINGL(row->key, row->key_len);
-        row->unlock();
-    } else {
+    auto row = table->current();
+    if (row->key_len == 0) {
         RETURN_NULL();
     }
+    RETVAL_STRINGL(row->key, row->key_len);
 }
 
 static PHP_METHOD(swoole_table, next) {
     Table *table = php_swoole_table_get_and_check_ptr2(ZEND_THIS);
     table->forward();
 }
-
-static PHP_METHOD(swoole_table, valid) {
-    Table *table = php_swoole_table_get_and_check_ptr2(ZEND_THIS);
-    TableRow *row = table->current();
-    RETURN_BOOL(row != nullptr);
-}
-
-static PHP_METHOD(swoole_table_row, offsetExists) {
-    char *key;
-    size_t keylen;
-
-    if (zend_parse_parameters(ZEND_NUM_ARGS(), "s", &key, &keylen) == FAILURE) {
-        RETURN_FALSE;
-    }
-
-    zval *zprop_value = sw_zend_read_property_ex(swoole_table_row_ce, ZEND_THIS, SW_ZSTR_KNOWN(SW_ZEND_STR_VALUE), 0);
-    RETURN_BOOL(zend_hash_str_exists(Z_ARRVAL_P(zprop_value), key, keylen));
-}
-
-static PHP_METHOD(swoole_table_row, offsetGet) {
-    char *key;
-    size_t keylen;
-
-    if (zend_parse_parameters(ZEND_NUM_ARGS(), "s", &key, &keylen) == FAILURE) {
-        RETURN_FALSE;
-    }
-
-    zval *zprop_value = sw_zend_read_property_ex(swoole_table_row_ce, ZEND_THIS, SW_ZSTR_KNOWN(SW_ZEND_STR_VALUE), 0);
-    zval *retval = nullptr;
-    if (!(retval = zend_hash_str_find(Z_ARRVAL_P(zprop_value), key, keylen))) {
-        RETURN_FALSE;
-    }
-    RETURN_ZVAL(retval, 1, 0);
-}
-
-static PHP_METHOD(swoole_table_row, offsetSet) {
-    Table *table = php_swoole_table_row_get_and_check_ptr(ZEND_THIS);
-    zval *value;
-    char *key;
-    size_t keylen;
-
-    if (zend_parse_parameters(ZEND_NUM_ARGS(), "sz", &key, &keylen, &value) == FAILURE) {
-        RETURN_FALSE;
-    }
-
-    zval *zprop_key = sw_zend_read_property_ex(swoole_table_row_ce, ZEND_THIS, SW_ZSTR_KNOWN(SW_ZEND_STR_KEY), 0);
-
-    int out_flags;
-    TableRow *_rowlock = nullptr;
-    TableRow *row = table->set(Z_STRVAL_P(zprop_key), Z_STRLEN_P(zprop_key), &_rowlock, &out_flags);
-    if (!row) {
-        _rowlock->unlock();
-        php_swoole_error(E_WARNING, "Unable to allocate memory");
-        RETURN_FALSE;
-    }
-
-    if (out_flags & SW_TABLE_FLAG_NEW_ROW) {
-        for (auto i = table->column_list->begin(); i != table->column_list->end(); i++) {
-            (*i)->clear(row);
-        }
-    }
-
-    TableColumn *column = table->get_column(std::string(key, keylen));
-    if (column == nullptr) {
-        _rowlock->unlock();
-        php_swoole_fatal_error(E_WARNING, "column[%s] does not exist", key);
-        RETURN_FALSE;
-    }
-
-    if (column->type == TableColumn::TYPE_STRING) {
-        zend_string *str = zval_get_string(value);
-        row->set_value(column, ZSTR_VAL(str), ZSTR_LEN(str));
-        zend_string_release(str);
-    } else if (column->type == TableColumn::TYPE_FLOAT) {
-        double _value = zval_get_double(value);
-        row->set_value(column, &_value, 0);
-    } else {
-        long _value = zval_get_long(value);
-        row->set_value(column, &_value, 0);
-    }
-    _rowlock->unlock();
-
-    zval *zprop_value = sw_zend_read_property_ex(swoole_table_row_ce, ZEND_THIS, SW_ZSTR_KNOWN(SW_ZEND_STR_VALUE), 0);
-    Z_TRY_ADDREF_P(value);
-    add_assoc_zval_ex(zprop_value, key, keylen, value);
-
-    RETURN_TRUE;
-}
-
-static PHP_METHOD(swoole_table_row, offsetUnset) {
-    php_swoole_fatal_error(E_WARNING, "not supported");
-    RETURN_FALSE;
-}
-
-static PHP_METHOD(swoole_table_row, __destruct) {}
