@@ -205,8 +205,6 @@ typedef swoole::Protocol swProtocol;
 typedef swoole::EventData swEventData;
 typedef swoole::DataHead swDataHead;
 typedef swoole::Event swEvent;
-typedef swoole::Pipe swPipe;
-typedef swoole::Callback swCallback;
 
 /*----------------------------------String-------------------------------------*/
 
@@ -342,12 +340,12 @@ static inline void swoole_strtolower(char *str, int length) {
 }
 
 /*--------------------------------Constants------------------------------------*/
-enum swResult_code {
+enum swResultCode {
     SW_OK  = 0,
     SW_ERR = -1,
 };
 
-enum swReturn_code {
+enum swReturnCode {
     SW_CONTINUE = 1,
     SW_WAIT     = 2,
     SW_CLOSE    = 3,
@@ -356,7 +354,7 @@ enum swReturn_code {
     SW_INVALID  = 6,
 };
 
-enum swFd_type {
+enum swFdType {
     SW_FD_SESSION,        // server stream session
     SW_FD_STREAM_SERVER,  // server stream port
     SW_FD_DGRAM_SERVER,   // server dgram port
@@ -380,6 +378,7 @@ enum swFd_type {
      */
     SW_FD_SIGNAL,
     SW_FD_DNS_RESOLVER,
+    SW_FD_CARES,
     /**
      * SW_FD_USER or SW_FD_USER+n: for custom event
      */
@@ -388,13 +387,13 @@ enum swFd_type {
     SW_FD_DGRAM_CLIENT,
 };
 
-enum swSocket_flag {
+enum swSocketFlag {
     SW_SOCK_NONBLOCK = 1 << 2,
     SW_SOCK_CLOEXEC  = 1 << 3,
     SW_SOCK_SSL      = (1u << 9),
 };
 
-enum swSocket_type {
+enum swSocketType {
     SW_SOCK_TCP         = 1,
     SW_SOCK_UDP         = 2,
     SW_SOCK_TCP6        = 3,
@@ -404,7 +403,7 @@ enum swSocket_type {
     SW_SOCK_RAW         = 7,
 };
 
-enum swEvent_type {
+enum swEventType {
     SW_EVENT_NULL   = 0,
     SW_EVENT_DEAULT = 1u << 8,
     SW_EVENT_READ   = 1u << 9,
@@ -414,7 +413,7 @@ enum swEvent_type {
     SW_EVENT_ONCE   = 1u << 12,
 };
 
-enum swFork_type {
+enum swForkType {
     SW_FORK_SPAWN    = 0,
     SW_FORK_EXEC     = 1 << 1,
     SW_FORK_DAEMON   = 1 << 2,
@@ -450,7 +449,7 @@ static sw_inline size_t swoole_size_align(size_t size, int pagesize) {
 }
 
 //------------------------------Base--------------------------------
-enum swEventData_flag {
+enum swEventDataFlag {
     SW_EVENT_DATA_NORMAL,
     SW_EVENT_DATA_PTR     = 1u << 1,
     SW_EVENT_DATA_CHUNK   = 1u << 2,
@@ -460,12 +459,12 @@ enum swEventData_flag {
     SW_EVENT_DATA_POP_PTR = 1u << 6,
 };
 
-#define swTask_type(task) ((task)->info.server_fd)
-
 /**
- * use swDataHead->server_fd, 1 byte 8 bit
+ * Use server_fd field to store flag of the server task
  */
-enum swTask_type {
+#define SW_TASK_TYPE(task) ((task)->info.server_fd)
+
+enum swTaskType {
     SW_TASK_TMPFILE   = 1,    // tmp file
     SW_TASK_SERIALIZE = 2,    // php serialize
     SW_TASK_NONBLOCK  = 4,    // task
@@ -476,7 +475,7 @@ enum swTask_type {
     SW_TASK_NOREPLY   = 128,  // don't reply
 };
 
-enum swDNSLookup_cache_type {
+enum swDNSLookupFlag {
     SW_DNS_LOOKUP_RANDOM = (1u << 11),
 };
 
@@ -487,7 +486,7 @@ char *sw_error_();
 extern __thread char sw_error[SW_ERROR_MSG_SIZE];
 #endif
 
-enum swProcess_type {
+enum swProcessType {
     SW_PROCESS_MASTER     = 1,
     SW_PROCESS_WORKER     = 2,
     SW_PROCESS_MANAGER    = 3,
@@ -495,7 +494,7 @@ enum swProcess_type {
     SW_PROCESS_USERWORKER = 5,
 };
 
-enum swPipe_type {
+enum swPipeType {
     SW_PIPE_WORKER   = 0,
     SW_PIPE_MASTER   = 1,
     SW_PIPE_READ     = 0,
@@ -564,16 +563,20 @@ static inline struct timespec swoole_time_until(int milliseconds) {
 }
 
 namespace swoole {
-struct Event {
-    int fd;
-    int16_t reactor_id;
-    enum swFd_type type;
-    network::Socket *socket;
-};
 
 typedef long SessionId;
 typedef long TaskId;
 typedef uint8_t ReactorId;
+typedef enum swEventType EventType;
+typedef enum swSocketType SocketType;
+typedef enum swFdType FdType;
+
+struct Event {
+    int fd;
+    int16_t reactor_id;
+    FdType type;
+    network::Socket *socket;
+};
 
 struct DataHead {
     SessionId fd;
@@ -633,7 +636,7 @@ struct Global {
     int signal_fd;
     bool signal_alarm;
 
-    uint32_t trace_flags;
+    long trace_flags;
 
     void (*fatal_error)(int code, const char *str, ...);
 
@@ -642,23 +645,30 @@ struct Global {
     uint32_t pagesize;
     struct utsname uname;
     uint32_t max_sockets;
+    uint32_t max_concurrency;
     //-----------------------[Memory]--------------------------
     MemoryPool *memory_pool;
     Allocator std_allocator;
     std::string task_tmpfile;
     //-----------------------[DNS]--------------------------
-    char *dns_server_v4;
-    char *dns_server_v6;
+    std::string dns_server_host;
+    int dns_server_port;
     double dns_cache_refresh_time;
+    int dns_tries;
+    std::string dns_resolvconf_path;
+    std::string dns_hosts_path;
     //-----------------------[AIO]--------------------------
     uint32_t aio_core_worker_num;
     uint32_t aio_worker_num;
     double aio_max_wait_time;
     double aio_max_idle_time;
-    swoole::network::Socket *aio_default_socket;
+    network::Socket *aio_default_socket;
     //-----------------------[Hook]--------------------------
     void *hooks[SW_MAX_HOOK_TYPE];
-    std::function<bool(swoole::Reactor *reactor, int &event_num)> user_exit_condition;
+    std::function<bool(Reactor *reactor, int &event_num)> user_exit_condition;
+
+    // bug report message
+    std::string bug_report_message = "";
 };
 
 std::string dirname(const std::string &file);
@@ -694,6 +704,12 @@ static inline int swoole_get_process_id() {
 
 SW_API const char *swoole_strerror(int code);
 SW_API void swoole_throw_error(int code);
+SW_API void swoole_set_log_level(int level);
+SW_API void swoole_set_trace_flags(int flags);
+SW_API void swoole_set_dns_server(const std::string &server);
+SW_API void swoole_set_hosts_path(const std::string &hosts_file);
+SW_API std::pair<std::string, int> swoole_get_dns_server();
+SW_API bool swoole_load_resolv_conf();
 
 //-----------------------------------------------
 static sw_inline void sw_spinlock(sw_atomic_t *lock) {
