@@ -76,7 +76,7 @@
 #else
 #define SW_IPC_MAX_SIZE 8192  // for IPC, dgram and message-queue max size
 #endif
-#define SW_IPC_BUFFER_SIZE (SW_IPC_MAX_SIZE - sizeof(swDataHead))
+#define SW_IPC_BUFFER_SIZE (SW_IPC_MAX_SIZE - sizeof(swoole::DataHead))
 // !!!End.-------------------------------------------------------------------
 
 #define SW_BUFFER_SIZE_STD 8192
@@ -191,7 +191,7 @@
 
 #define SW_DNS_HOST_BUFFER_SIZE 16
 #define SW_DNS_SERVER_PORT 53
-#define SW_DNS_DEFAULT_SERVER "8.8.8.8"
+#define SW_DNS_RESOLV_CONF "/etc/resolv.conf"
 
 #define SW_Z_BEST_SPEED 1
 #define SW_COMPRESSION_MIN_LENGTH_DEFAULT  20
