@@ -38,10 +38,14 @@ enum swErrorCode {
     SW_ERROR_FILE_NOT_EXIST = 700,
     SW_ERROR_FILE_TOO_LARGE,
     SW_ERROR_FILE_EMPTY,
-    SW_ERROR_DNSLOOKUP_DUPLICATE_REQUEST,
+
+    SW_ERROR_DNSLOOKUP_DUPLICATE_REQUEST = 710,
     SW_ERROR_DNSLOOKUP_RESOLVE_FAILED,
     SW_ERROR_DNSLOOKUP_RESOLVE_TIMEOUT,
-    SW_ERROR_BAD_IPV6_ADDRESS,
+    SW_ERROR_DNSLOOKUP_UNSUPPORTED,
+    SW_ERROR_DNSLOOKUP_NO_SERVER,
+
+    SW_ERROR_BAD_IPV6_ADDRESS = 720,
     SW_ERROR_UNREGISTERED_SIGNAL,
 
     // EventLoop
@@ -167,6 +171,11 @@ enum swErrorCode {
     SW_ERROR_CO_STD_THREAD_LINK_ERROR,
     SW_ERROR_CO_DISABLED_MULTI_THREAD,
 
+    SW_ERROR_CO_CANNOT_CANCEL,
+    SW_ERROR_CO_NOT_EXISTS,
+    SW_ERROR_CO_CANCELED,
+    SW_ERROR_CO_TIMEDOUT,
+
     SW_ERROR_END
 };
 
