@@ -24,6 +24,7 @@
 
 #include "swoole_lock.h"
 #include "swoole_pipe.h"
+#include "swoole_channel.h"
 #include "swoole_msg_queue.h"
 
 enum swWorker_status {
@@ -86,21 +87,13 @@ struct ProcessPool;
 struct Worker;
 
 struct WorkerGlobal {
-    /**
-     * Always run
-     */
     bool run_always;
     bool shutdown;
-    /**
-     * pipe_worker
-     */
-    int pipe_used;
-
     uint32_t max_request;
-
     String **output_buffer;
     Worker *worker;
     time_t exit_time;
+    uint32_t worker_concurrency = 0;
 };
 
 struct Worker {
@@ -138,6 +131,7 @@ struct Worker {
 
     long dispatch_count;
     long request_count;
+    size_t coroutine_num;
 
     /**
      * worker id
@@ -156,6 +150,18 @@ struct Worker {
     void *ptr2;
 
     ssize_t send_pipe_message(const void *buf, size_t n, int flags);
+
+    void set_status(enum swWorker_status _status) {
+        status = _status;
+    }
+
+    bool is_busy() {
+        return status == SW_WORKER_BUSY;
+    }
+
+    bool is_idle() {
+        return status == SW_WORKER_IDLE;
+    }
 };
 
 struct StreamInfo {
@@ -173,8 +179,9 @@ struct ProcessPool {
     bool reloading;
     bool running;
     bool reload_init;
+    bool read_message;
     bool started;
-    uint8_t dispatch_mode;
+    bool schedule_by_sysvmsg;
     uint8_t ipc_mode;
     pid_t master_pid;
     uint32_t reload_worker_i;
@@ -234,6 +241,7 @@ struct ProcessPool {
     Reactor *reactor;
     MsgQueue *queue;
     StreamInfo *stream_info_;
+    Channel *message_box = nullptr;
 
     void *ptr;
 
@@ -257,9 +265,18 @@ struct ProcessPool {
         return &(workers[worker_id - start_id]);
     }
 
+    Worker *get_worker_by_pid(pid_t pid) {
+        auto iter = map_->find(pid);
+        if (iter == map_->end()) {
+            return nullptr;
+        }
+        return iter->second;
+    }
+
     void set_max_request(uint32_t _max_request, uint32_t _max_request_grace);
     int get_max_request();
-    int set_protocol(int task_protocol, uint32_t max_packet_size);
+    void set_protocol(int task_protocol, uint32_t max_packet_size);
+    bool detach();
     int wait();
     int start();
     void shutdown();
@@ -275,6 +292,7 @@ struct ProcessPool {
     int listen(const char *socket_file, int blacklog);
     int listen(const char *host, int port, int blacklog);
     int schedule();
+    static void kill_timeout_worker(Timer *timer, TimerNode *tnode);
 };
 };  // namespace swoole
 
@@ -287,9 +305,6 @@ static sw_inline int swoole_waitpid(pid_t __pid, int *__stat_loc, int __options)
 }
 
 static sw_inline int swoole_kill(pid_t __pid, int __sig) {
-    if (__pid <= 0) {
-        return -1;
-    }
     return kill(__pid, __sig);
 }
 
