@@ -73,9 +73,42 @@ struct TableRow {
 };
 
 struct TableIterator {
+    size_t row_memory_size_;
     uint32_t absolute_index;
     uint32_t collision_index;
-    TableRow *row;
+    TableRow *current_;
+    Mutex *mutex_;
+
+    TableIterator(size_t row_size) {
+        current_ = (TableRow *) sw_malloc(row_size);
+        if (!current_) {
+            throw std::bad_alloc();
+        }
+        mutex_ = new Mutex(Mutex::PROCESS_SHARED);
+        row_memory_size_ = row_size;
+        reset();
+    }
+
+    void lock() {
+        mutex_->lock();
+    }
+
+    void unlock() {
+        mutex_->unlock();
+    }
+
+    void reset() {
+        absolute_index = 0;
+        collision_index = 0;
+        sw_memset_zero(current_, row_memory_size_);
+    }
+
+    ~TableIterator() {
+        if (current_) {
+            sw_free(current_);
+        }
+        delete mutex_;
+    }
 };
 
 enum TableFlag {
@@ -183,6 +216,14 @@ class Table {
         return size;
     }
 
+    int lock() {
+        return mutex->lock();
+    }
+
+    int unlock() {
+        return mutex->unlock();
+    }
+
     TableRow *get_by_index(uint32_t index) {
         TableRow *row = rows[index];
         return row->active ? row : nullptr;
@@ -201,12 +242,25 @@ class Table {
         return row_num;
     }
 
+    bool exists(const char *key, uint16_t keylen) {
+        TableRow *_rowlock = nullptr;
+        const TableRow *row = get(key, keylen, &_rowlock);
+        _rowlock->unlock();
+        return row != nullptr;
+    }
+
+    bool exists(const std::string &key) {
+        return exists(key.c_str(), key.length());
+    }
+
     TableRow *current() {
-        return iterator->row;
+        return iterator->current_;
     }
 
     void rewind() {
-        sw_memset_zero(iterator, sizeof(*iterator));
+        iterator->lock();
+        iterator->reset();
+        iterator->unlock();
     }
 
     TableRow *hash(const char *key, int keylen) {
