@@ -59,6 +59,10 @@ const char *swoole_strerror(int code) {
         return "DNS Lookup resolve failed";
     case SW_ERROR_DNSLOOKUP_RESOLVE_TIMEOUT:
         return "DNS Lookup resolve timeout";
+    case SW_ERROR_DNSLOOKUP_UNSUPPORTED:
+        return "DNS Lookup unsupported";
+    case SW_ERROR_DNSLOOKUP_NO_SERVER:
+        return "DNS Lookup no server";
     case SW_ERROR_BAD_IPV6_ADDRESS:
         return "Bad ipv6 address";
     case SW_ERROR_UNREGISTERED_SIGNAL:
@@ -215,6 +219,14 @@ const char *swoole_strerror(int code) {
         return "Coroutine std thread link error";
     case SW_ERROR_CO_DISABLED_MULTI_THREAD:
         return "Coroutine disabled multi thread";
+    case SW_ERROR_CO_CANNOT_CANCEL:
+        return "Coroutine cannot cancel";
+    case SW_ERROR_CO_NOT_EXISTS:
+        return "Coroutine not exists";
+    case SW_ERROR_CO_CANCELED:
+        return "Coroutine canceled";
+    case SW_ERROR_CO_TIMEDOUT:
+        return "Coroutine timedout";
     default:
         static char buffer[32];
 #ifndef __MACH__
