@@ -40,7 +40,7 @@ bool SocketPair::init_socket(int master_fd, int worker_fd) {
 
 Pipe::Pipe(bool _blocking) : SocketPair(_blocking) {
     if (pipe(socks) < 0) {
-        swSysWarn("pipe() failed");
+        swoole_sys_warning("pipe() failed");
         return;
     }
     if (!init_socket(socks[1], socks[0])) {
