@@ -23,32 +23,44 @@
 #ifdef HAVE_SIGNALFD
 #include <sys/signalfd.h>
 #endif
+
 #ifdef HAVE_KQUEUE
+#ifdef USE_KQUEUE_IDE_HELPER
+#include "helper/kqueue.h"
+#else
 #include <sys/event.h>
 #endif
+#endif
 
+using swoole::Event;
 using swoole::Reactor;
+using swoole::Signal;
+using swoole::SignalHandler;
+using swoole::network::Socket;
 
 #ifdef HAVE_SIGNALFD
-static swSignalHandler swSignalfd_set(int signo, swSignalHandler handler);
-static bool swSignalfd_create();
-static void swSignalfd_clear();
-static int swSignalfd_onSignal(Reactor *reactor, swEvent *event);
-#elif HAVE_KQUEUE
-static swSignalHandler swKqueueSignal_set(int signo, swSignalHandler handler);
+static SignalHandler swoole_signalfd_set(int signo, SignalHandler handler);
+static bool swoole_signalfd_create();
+static void swoole_signalfd_clear();
+static int swoole_signalfd_event_callback(Reactor *reactor, Event *event);
 #endif
-static void swSignal_async_handler(int signo);
+
+#ifdef HAVE_KQUEUE
+static SignalHandler swoole_signal_kqueue_set(int signo, SignalHandler handler);
+#endif
+
+static void swoole_signal_async_handler(int signo);
 
 #ifdef HAVE_SIGNALFD
 static sigset_t signalfd_mask;
 static int signal_fd = 0;
 static pid_t signalfd_create_pid;
-static swoole::network::Socket *signal_socket = nullptr;
+static Socket *signal_socket = nullptr;
 #endif
-static swSignal signals[SW_SIGNO_MAX];
+static Signal signals[SW_SIGNO_MAX];
 static int _lock = 0;
 
-char *swSignal_str(int sig) {
+char *swoole_signal_to_str(int sig) {
     static char buf[64];
     snprintf(buf, sizeof(buf), "%s", strsignal(sig));
     if (strchr(buf, ':') == 0) {
@@ -61,19 +73,19 @@ char *swSignal_str(int sig) {
 /**
  * block all singal
  */
-void swSignal_none(void) {
+void swoole_signal_block_all(void) {
     sigset_t mask;
     sigfillset(&mask);
     int ret = pthread_sigmask(SIG_BLOCK, &mask, nullptr);
     if (ret < 0) {
-        swSysWarn("pthread_sigmask() failed");
+        swoole_sys_warning("pthread_sigmask() failed");
     }
 }
 
 /**
  * set new signal handler and return origin signal handler
  */
-swSignalHandler swSignal_set(int signo, swSignalHandler func, int restart, int mask) {
+SignalHandler swoole_signal_set(int signo, SignalHandler func, int restart, int mask) {
     // ignore
     if (func == nullptr) {
         func = SIG_IGN;
@@ -101,10 +113,10 @@ swSignalHandler swSignal_set(int signo, swSignalHandler func, int restart, int m
 /**
  * set new signal handler and return origin signal handler
  */
-swSignalHandler swSignal_set(int signo, swSignalHandler handler) {
+SignalHandler swoole_signal_set(int signo, SignalHandler handler) {
 #ifdef HAVE_SIGNALFD
     if (SwooleG.use_signalfd) {
-        return swSignalfd_set(signo, handler);
+        return swoole_signalfd_set(signo, handler);
     } else
 #endif
     {
@@ -113,19 +125,19 @@ swSignalHandler swSignal_set(int signo, swSignalHandler handler) {
         // see https://www.freebsd.org/cgi/man.cgi?kqueue
         // if there's no main reactor, signals cannot be monitored either
         if (signo != SIGCHLD && sw_reactor()) {
-            return swKqueueSignal_set(signo, handler);
+            return swoole_signal_kqueue_set(signo, handler);
         } else
 #endif
         {
             signals[signo].handler = handler;
             signals[signo].activated = true;
             signals[signo].signo = signo;
-            return swSignal_set(signo, swSignal_async_handler, 1, 0);
+            return swoole_signal_set(signo, swoole_signal_async_handler, 1, 0);
         }
     }
 }
 
-static void swSignal_async_handler(int signo) {
+static void swoole_signal_async_handler(int signo) {
     if (sw_reactor()) {
         sw_reactor()->singal_no = signo;
     } else {
@@ -134,37 +146,38 @@ static void swSignal_async_handler(int signo) {
             return;
         }
         _lock = 1;
-        swSignal_callback(signo);
+        swoole_signal_callback(signo);
         _lock = 0;
     }
 }
 
-void swSignal_callback(int signo) {
+void swoole_signal_callback(int signo) {
     if (signo >= SW_SIGNO_MAX) {
-        swWarn("signal[%d] numberis invalid", signo);
+        swoole_warning("signal[%d] numberis invalid", signo);
         return;
     }
-    swSignalHandler callback = signals[signo].handler;
+    SignalHandler callback = signals[signo].handler;
     if (!callback) {
-        swoole_error_log(SW_LOG_WARNING, SW_ERROR_UNREGISTERED_SIGNAL, SW_UNREGISTERED_SIGNAL_FMT, swSignal_str(signo));
+        swoole_error_log(
+            SW_LOG_WARNING, SW_ERROR_UNREGISTERED_SIGNAL, SW_UNREGISTERED_SIGNAL_FMT, swoole_signal_to_str(signo));
         return;
     }
     callback(signo);
 }
 
-swSignalHandler swSignal_get_handler(int signo) {
+SignalHandler swoole_signal_get_handler(int signo) {
     if (signo >= SW_SIGNO_MAX) {
-        swWarn("signal[%d] numberis invalid", signo);
+        swoole_warning("signal[%d] numberis invalid", signo);
         return nullptr;
     } else {
         return signals[signo].handler;
     }
 }
 
-void swSignal_clear(void) {
+void swoole_signal_clear(void) {
 #ifdef HAVE_SIGNALFD
     if (SwooleG.use_signalfd) {
-        swSignalfd_clear();
+        swoole_signalfd_clear();
     } else
 #endif
     {
@@ -173,11 +186,11 @@ void swSignal_clear(void) {
             if (signals[i].activated) {
 #ifdef HAVE_KQUEUE
                 if (signals[i].signo != SIGCHLD && sw_reactor()) {
-                    swKqueueSignal_set(signals[i].signo, nullptr);
+                    swoole_signal_kqueue_set(signals[i].signo, nullptr);
                 } else
 #endif
                 {
-                    swSignal_set(signals[i].signo, (swSignalHandler) -1, 1, 0);
+                    swoole_signal_set(signals[i].signo, (SignalHandler) -1, 1, 0);
                 }
             }
         }
@@ -186,7 +199,7 @@ void swSignal_clear(void) {
 }
 
 #ifdef HAVE_SIGNALFD
-void swSignalfd_init() {
+void swoole_signalfd_init() {
     sigemptyset(&signalfd_mask);
     sw_memset_zero(&signals, sizeof(signals));
 }
@@ -194,12 +207,12 @@ void swSignalfd_init() {
 /**
  * set new signal handler and return origin signal handler
  */
-static swSignalHandler swSignalfd_set(int signo, swSignalHandler handler) {
-    swSignalHandler origin_handler = nullptr;
+static SignalHandler swoole_signalfd_set(int signo, SignalHandler handler) {
+    SignalHandler origin_handler = nullptr;
 
     if (handler == nullptr && signals[signo].activated) {
         sigdelset(&signalfd_mask, signo);
-        sw_memset_zero(&signals[signo], sizeof(swSignal));
+        sw_memset_zero(&signals[signo], sizeof(Signal));
     } else {
         sigaddset(&signalfd_mask, signo);
         origin_handler = signals[signo].handler;
@@ -210,33 +223,35 @@ static swSignalHandler swSignalfd_set(int signo, swSignalHandler handler) {
 
     if (sw_reactor()) {
         if (signal_fd == 0) {
-            swSignalfd_create();
+            swoole_signalfd_create();
         } else {
             sigprocmask(SIG_SETMASK, &signalfd_mask, nullptr);
             signalfd(signal_fd, &signalfd_mask, SFD_NONBLOCK | SFD_CLOEXEC);
         }
-        swSignalfd_setup(sw_reactor());
+        swoole_signalfd_setup(sw_reactor());
     }
 
     return origin_handler;
 }
 
-static bool swSignalfd_create() {
+static bool swoole_signalfd_create() {
     if (signal_fd != 0) {
         return false;
     }
 
     signal_fd = signalfd(-1, &signalfd_mask, SFD_NONBLOCK | SFD_CLOEXEC);
     if (signal_fd < 0) {
-        swSysWarn("signalfd() failed");
+        swoole_sys_warning("signalfd() failed");
+        signal_fd = 0;
         return false;
     }
     signal_socket = swoole::make_socket(signal_fd, SW_FD_SIGNAL);
     if (sigprocmask(SIG_BLOCK, &signalfd_mask, nullptr) == -1) {
-        swSysWarn("sigprocmask() failed");
+        swoole_sys_warning("sigprocmask() failed");
         signal_socket->fd = -1;
         signal_socket->free();
         close(signal_fd);
+        signal_socket = nullptr;
         signal_fd = 0;
         return false;
     }
@@ -246,12 +261,12 @@ static bool swSignalfd_create() {
     return true;
 }
 
-bool swSignalfd_setup(Reactor *reactor) {
-    if (signal_fd == 0 && !swSignalfd_create()) {
+bool swoole_signalfd_setup(Reactor *reactor) {
+    if (signal_fd == 0 && !swoole_signalfd_create()) {
         return false;
     }
     if (!swoole_event_isset_handler(SW_FD_SIGNAL)) {
-        swoole_event_set_handler(SW_FD_SIGNAL, swSignalfd_onSignal);
+        swoole_event_set_handler(SW_FD_SIGNAL, swoole_signalfd_event_callback);
         reactor->set_exit_condition(Reactor::EXIT_CONDITION_SIGNALFD, [](Reactor *reactor, int &event_num) -> bool {
             event_num--;
             return true;
@@ -269,10 +284,10 @@ bool swSignalfd_setup(Reactor *reactor) {
     return true;
 }
 
-static void swSignalfd_clear() {
+static void swoole_signalfd_clear() {
     if (signal_fd) {
         if (sigprocmask(SIG_UNBLOCK, &signalfd_mask, nullptr) < 0) {
-            swSysWarn("sigprocmask(SIG_UNBLOCK) failed");
+            swoole_sys_warning("sigprocmask(SIG_UNBLOCK) failed");
         }
         if (signal_socket) {
             signal_socket->free();
@@ -283,19 +298,19 @@ static void swSignalfd_clear() {
     SwooleG.signal_fd = signal_fd = 0;
 }
 
-static int swSignalfd_onSignal(Reactor *reactor, swEvent *event) {
+static int swoole_signalfd_event_callback(Reactor *reactor, Event *event) {
     struct signalfd_siginfo siginfo;
     ssize_t n = read(event->fd, &siginfo, sizeof(siginfo));
     if (n < 0) {
-        swSysWarn("read from signalfd failed");
+        swoole_sys_warning("read from signalfd failed");
         return SW_OK;
     }
     if (siginfo.ssi_signo >= SW_SIGNO_MAX) {
-        swWarn("unknown signal[%d]", siginfo.ssi_signo);
+        swoole_warning("unknown signal[%d]", siginfo.ssi_signo);
         return SW_OK;
     }
     if (signals[siginfo.ssi_signo].activated) {
-        swSignalHandler handler = signals[siginfo.ssi_signo].handler;
+        SignalHandler handler = signals[siginfo.ssi_signo].handler;
         if (handler == SIG_IGN) {
             return SW_OK;
         } else if (handler) {
@@ -304,7 +319,7 @@ static int swSignalfd_onSignal(Reactor *reactor, swEvent *event) {
             swoole_error_log(SW_LOG_WARNING,
                              SW_ERROR_UNREGISTERED_SIGNAL,
                              SW_UNREGISTERED_SIGNAL_FMT,
-                             swSignal_str(siginfo.ssi_signo));
+                             swoole_signal_to_str(siginfo.ssi_signo));
         }
     }
 
@@ -316,15 +331,15 @@ static int swSignalfd_onSignal(Reactor *reactor, swEvent *event) {
 /**
  * set new signal handler and return origin signal handler
  */
-static swSignalHandler swKqueueSignal_set(int signo, swSignalHandler handler) {
+static SignalHandler swoole_signal_kqueue_set(int signo, SignalHandler handler) {
     struct kevent ev;
-    swSignalHandler origin_handler = nullptr;
+    SignalHandler origin_handler = nullptr;
     Reactor *reactor = sw_reactor();
 
     // clear signal
     if (handler == nullptr) {
         signal(signo, SIG_DFL);
-        sw_memset_zero(&signals[signo], sizeof(swSignal));
+        sw_memset_zero(&signals[signo], sizeof(Signal));
         EV_SET(&ev, signo, EVFILT_SIGNAL, EV_DELETE, 0, 0, NULL);
     }
     // add/update signal
@@ -344,7 +359,7 @@ static swSignalHandler swKqueueSignal_set(int signo, swSignalHandler handler) {
     }
     int n = kevent(reactor->native_handle, &ev, 1, nullptr, 0, nullptr);
     if (n < 0 && sw_unlikely(handler)) {
-        swSysWarn("kevent set signal[%d] error", signo);
+        swoole_sys_warning("kevent set signal[%d] error", signo);
     }
 
     return origin_handler;
