@@ -21,7 +21,7 @@ namespace swoole {
 UnixSocket::UnixSocket(bool blocking, int _protocol) :
         SocketPair(blocking), protocol_(_protocol) {
     if (socketpair(AF_UNIX, protocol_, 0, socks) < 0) {
-        swSysWarn("socketpair() failed");
+        swoole_sys_warning("socketpair() failed");
         return;
     }
     if (!init_socket(socks[1], socks[0])) {
