@@ -23,9 +23,10 @@
 #include "swoole_server.h"
 #include "swoole_redis.h"
 
-using namespace swoole;
+namespace swoole {
+namespace redis {
 
-struct RedisRequest {
+struct Request {
     uint8_t state;
 
     int n_lines_total;
@@ -37,25 +38,25 @@ struct RedisRequest {
     int offset;
 };
 
-int swRedis_recv_packet(Protocol *protocol, Connection *conn, String *buffer) {
+int recv_packet(Protocol *protocol, Connection *conn, String *buffer) {
     const char *p, *pe;
     int ret;
     char *buf_ptr;
     size_t buf_size;
 
-    RedisRequest *request;
+    Request *request;
     network::Socket *socket = conn->socket;
 
     if (conn->object == nullptr) {
-        request = (RedisRequest *) sw_malloc(sizeof(RedisRequest));
+        request = (Request *) sw_malloc(sizeof(Request));
         if (!request) {
-            swWarn("malloc(%ld) failed", sizeof(RedisRequest));
+            swoole_warning("malloc(%ld) failed", sizeof(Request));
             return SW_ERR;
         }
-        sw_memset_zero(request, sizeof(RedisRequest));
+        sw_memset_zero(request, sizeof(Request));
         conn->object = request;
     } else {
-        request = (RedisRequest *) conn->object;
+        request = (Request *) conn->object;
     }
 
 _recv_data:
@@ -66,7 +67,7 @@ _recv_data:
     if (n < 0) {
         switch (socket->catch_error(errno)) {
         case SW_ERROR:
-            swSysWarn("recv from socket#%d failed", conn->fd);
+            swoole_sys_warning("recv from socket#%d failed", conn->fd);
             return SW_OK;
         case SW_CLOSE:
             return SW_ERR;
@@ -89,7 +90,7 @@ _recv_data:
                 }
             } else if (buffer->length == buffer->size) {
             _package_too_big:
-                swWarn("Package is too big. package_length=%ld", buffer->length);
+                swoole_warning("Package is too big. package_length=%ld", buffer->length);
                 return SW_ERR;
             }
             goto _recv_data;
@@ -100,10 +101,10 @@ _recv_data:
 
         do {
             switch (request->state) {
-            case SW_REDIS_RECEIVE_TOTAL_LINE:
-                if (*p == '*' && (p = swRedis_get_number(p, &ret))) {
+            case STATE_RECEIVE_TOTAL_LINE:
+                if (*p == '*' && (p = get_number(p, &ret))) {
                     request->n_lines_total = ret;
-                    request->state = SW_REDIS_RECEIVE_LENGTH;
+                    request->state = STATE_RECEIVE_LENGTH;
                     break;
                 }
                 if (p == nullptr) {
@@ -111,8 +112,8 @@ _recv_data:
                 }
                 /* no break */
 
-            case SW_REDIS_RECEIVE_LENGTH:
-                if (*p == '$' && (p = swRedis_get_number(p, &ret))) {
+            case STATE_RECEIVE_LENGTH:
+                if (*p == '$' && (p = get_number(p, &ret))) {
                     if (ret < 0) {
                         break;
                     }
@@ -120,11 +121,11 @@ _recv_data:
                         goto _package_too_big;
                     }
                     request->n_bytes_total = ret;
-                    request->state = SW_REDIS_RECEIVE_STRING;
+                    request->state = STATE_RECEIVE_STRING;
                     break;
                 }
                 // integer
-                else if (*p == ':' && (p = swRedis_get_number(p, &ret))) {
+                else if (*p == ':' && (p = get_number(p, &ret))) {
                     break;
                 }
                 if (p == nullptr) {
@@ -132,7 +133,7 @@ _recv_data:
                 }
                 /* no break */
 
-            case SW_REDIS_RECEIVE_STRING:
+            case STATE_RECEIVE_STRING:
                 if (pe - p < request->n_bytes_total - request->n_bytes_received) {
                     request->n_bytes_received += pe - p;
                     return SW_OK;
@@ -140,7 +141,7 @@ _recv_data:
                     p += request->n_bytes_total + SW_CRLF_LEN;
                     request->n_bytes_total = 0;
                     request->n_lines_received++;
-                    request->state = SW_REDIS_RECEIVE_LENGTH;
+                    request->state = STATE_RECEIVE_LENGTH;
                     buffer->offset = buffer->length;
 
                     if (request->n_lines_received == request->n_lines_total) {
@@ -151,7 +152,7 @@ _recv_data:
                             return SW_OK;
                         }
                         buffer->clear();
-                        sw_memset_zero(request, sizeof(RedisRequest));
+                        sw_memset_zero(request, sizeof(Request));
                         return SW_OK;
                     }
                 }
@@ -163,28 +164,28 @@ _recv_data:
         } while (p < pe);
     }
 _failed:
-    swWarn("redis protocol error");
+    swoole_warning("redis protocol error");
     return SW_ERR;
 }
 
-bool swRedis_format(String *buf) {
+bool format(String *buf) {
     return buf->append(SW_STRL(SW_REDIS_RETURN_NIL)) == SW_OK;
 }
 
-bool swRedis_format(String *buf, enum swRedis_reply_type type, const std::string &value) {
-    if (type == SW_REDIS_REPLY_STATUS) {
+bool format(String *buf, enum ReplyType type, const std::string &value) {
+    if (type == REPLY_STATUS) {
         if (value.empty()) {
             return buf->append(SW_STRL("+OK\r\n")) == SW_OK;
         } else {
             return buf->format("+%.*s\r\n", value.length(), value.c_str()) > 0;
         }
-    } else if (type == SW_REDIS_REPLY_ERROR) {
+    } else if (type == REPLY_ERROR) {
         if (value.empty()) {
             return buf->append(SW_STRL("-ERR\r\n")) == SW_OK;
         } else {
             return buf->format("-%.*s\r\n", value.length(), value.c_str()) > 0;
         }
-    } else if (type == SW_REDIS_REPLY_STRING) {
+    } else if (type == REPLY_STRING) {
         if (value.empty() or value.length() > SW_REDIS_MAX_STRING_SIZE) {
             return false;
         } else {
@@ -199,12 +200,12 @@ bool swRedis_format(String *buf, enum swRedis_reply_type type, const std::string
     return false;
 }
 
-bool swRedis_format(String *buf, enum swRedis_reply_type type, long value) {
+bool format(String *buf, enum ReplyType type, long value) {
     return buf->format(":%" PRId64 "\r\n", value) > 0;
 }
 
-std::vector<std::string> swRedis_parse(const char *data, size_t len) {
-    int state = SW_REDIS_RECEIVE_TOTAL_LINE;
+std::vector<std::string> parse(const char *data, size_t len) {
+    int state = STATE_RECEIVE_TOTAL_LINE;
 
     const char *p = data;
     const char *pe = p + len;
@@ -214,33 +215,33 @@ std::vector<std::string> swRedis_parse(const char *data, size_t len) {
     std::vector<std::string> result;
     do {
         switch (state) {
-        case SW_REDIS_RECEIVE_TOTAL_LINE:
-            if (*p == '*' && (p = swRedis_get_number(p, &ret))) {
-                state = SW_REDIS_RECEIVE_LENGTH;
+        case STATE_RECEIVE_TOTAL_LINE:
+            if (*p == '*' && (p = get_number(p, &ret))) {
+                state = STATE_RECEIVE_LENGTH;
                 break;
             }
             /* no break */
 
-        case SW_REDIS_RECEIVE_LENGTH:
-            if (*p == '$' && (p = swRedis_get_number(p, &ret))) {
+        case STATE_RECEIVE_LENGTH:
+            if (*p == '$' && (p = get_number(p, &ret))) {
                 if (ret == -1) {
                     break;
                 }
                 length = ret;
-                state = SW_REDIS_RECEIVE_STRING;
+                state = STATE_RECEIVE_STRING;
                 break;
             }
             // integer
-            else if (*p == ':' && (p = swRedis_get_number(p, &ret))) {
+            else if (*p == ':' && (p = get_number(p, &ret))) {
                 result.push_back(std::to_string(ret));
                 break;
             }
             /* no break */
 
-        case SW_REDIS_RECEIVE_STRING:
+        case STATE_RECEIVE_STRING:
             result.push_back(std::string(p, length));
             p += length + SW_CRLF_LEN;
-            state = SW_REDIS_RECEIVE_LENGTH;
+            state = STATE_RECEIVE_LENGTH;
             break;
 
         default:
@@ -250,3 +251,5 @@ std::vector<std::string> swRedis_parse(const char *data, size_t len) {
 
     return result;
 }
+}  // namespace redis
+}  // namespace swoole
