@@ -18,6 +18,7 @@
 #include "swoole_string.h"
 #include "swoole_socket.h"
 #include "swoole_ssl.h"
+#include "swoole_util.h"
 
 #ifdef SW_USE_OPENSSL
 
@@ -35,17 +36,17 @@ static int ssl_connection_index = 0;
 static int ssl_port_index = 0;
 static pthread_mutex_t *lock_array;
 
-static int swSSL_verify_callback(int ok, X509_STORE_CTX *x509_store);
+static int swoole_ssl_verify_callback(int ok, X509_STORE_CTX *x509_store);
 #ifndef OPENSSL_NO_RSA
-static RSA *swSSL_rsa_key_callback(SSL *ssl, int is_export, int key_length);
+static RSA *swoole_ssl_rsa_key_callback(SSL *ssl, int is_export, int key_length);
 #endif
 #if OPENSSL_VERSION_NUMBER < 0x10100000L
-static int swSSL_set_default_dhparam(SSL_CTX *ssl_context);
+static int swoole_ssl_set_default_dhparam(SSL_CTX *ssl_context);
 #endif
 
 #ifdef SW_SUPPORT_DTLS
-static int swSSL_generate_cookie(SSL *ssl, uchar *cookie, uint *cookie_len);
-static int swSSL_verify_cookie(SSL *ssl, const uchar *cookie, uint cookie_len);
+static int swoole_ssl_generate_cookie(SSL *ssl, uchar *cookie, uint *cookie_len);
+static int swoole_ssl_verify_cookie(SSL *ssl, const uchar *cookie, uint cookie_len);
 #endif
 
 #ifdef __GNUC__
@@ -54,9 +55,17 @@ static int swSSL_verify_cookie(SSL *ssl, const uchar *cookie, uint cookie_len);
 #define MAYBE_UNUSED
 #endif
 
-static void MAYBE_UNUSED swSSL_lock_callback(int mode, int type, const char *file, int line);
+std::string swoole_ssl_get_version_message() {
+    std::string message = swoole::std_string::format(
+        "OPENSSL_VERSION: %s\n",
+        OPENSSL_VERSION_TEXT);
 
-void swSSL_init(void) {
+    return message;
+}
+
+static void MAYBE_UNUSED swoole_ssl_lock_callback(int mode, int type, const char *file, int line);
+
+void swoole_ssl_init(void) {
     if (openssl_init) {
         return;
     }
@@ -72,28 +81,28 @@ void swSSL_init(void) {
 
     ssl_connection_index = SSL_get_ex_new_index(0, nullptr, nullptr, nullptr, nullptr);
     if (ssl_connection_index < 0) {
-        swError("SSL_get_ex_new_index() failed");
+        swoole_error("SSL_get_ex_new_index() failed");
         return;
     }
 
     ssl_port_index = SSL_get_ex_new_index(0, nullptr, nullptr, nullptr, nullptr);
     if (ssl_port_index < 0) {
-        swError("SSL_get_ex_new_index() failed");
+        swoole_error("SSL_get_ex_new_index() failed");
         return;
     }
 
     openssl_init = true;
 }
 
-int swSSL_get_ex_connection_index() {
+int swoole_ssl_get_ex_connection_index() {
     return ssl_connection_index;
 }
 
-int swSSL_get_ex_port_index() {
+int swoole_ssl_get_ex_port_index() {
     return ssl_port_index;
 }
 
-void swSSL_destroy() {
+void swoole_ssl_destroy() {
     if (!openssl_init) {
         return;
     }
@@ -114,7 +123,7 @@ void swSSL_destroy() {
     openssl_thread_safety_init = false;
 }
 
-static void MAYBE_UNUSED swSSL_lock_callback(int mode, int type, const char *file, int line) {
+static void MAYBE_UNUSED swoole_ssl_lock_callback(int mode, int type, const char *file, int line) {
     if (mode & CRYPTO_LOCK) {
         pthread_mutex_lock(&(lock_array[type]));
     } else {
@@ -128,23 +137,23 @@ static int ssl_error_cb(const char *str, size_t len, void *buf) {
     return 0;
 }
 
-const char *swSSL_get_error() {
+const char *swoole_ssl_get_error() {
     ERR_print_errors_cb(ssl_error_cb, sw_tg_buffer()->str);
 
     return sw_tg_buffer()->str;
 }
 
 #if OPENSSL_VERSION_NUMBER >= OPENSSL_VERSION_1_0_0
-static void MAYBE_UNUSED swSSL_id_callback(CRYPTO_THREADID *id) {
+static void MAYBE_UNUSED swoole_ssl_id_callback(CRYPTO_THREADID *id) {
     CRYPTO_THREADID_set_numeric(id, (ulong_t) pthread_self());
 }
 #else
-static ulong_t swSSL_id_callback(void) {
+static ulong_t swoole_ssl_id_callback(void) {
     return (ulong_t) pthread_self();
 }
 #endif
 
-void swSSL_init_thread_safety() {
+void swoole_ssl_init_thread_safety() {
     if (!openssl_init) {
         return;
     }
@@ -159,20 +168,20 @@ void swSSL_init_thread_safety() {
     }
 
 #if OPENSSL_VERSION_NUMBER >= OPENSSL_VERSION_1_0_0
-    (void) CRYPTO_THREADID_set_callback(swSSL_id_callback);
+    (void) CRYPTO_THREADID_set_callback(swoole_ssl_id_callback);
 #else
-    CRYPTO_set_id_callback(swSSL_id_callback);
+    CRYPTO_set_id_callback(swoole_ssl_id_callback);
 #endif
 
-    CRYPTO_set_locking_callback(swSSL_lock_callback);
+    CRYPTO_set_locking_callback(swoole_ssl_lock_callback);
     openssl_thread_safety_init = true;
 }
 
-bool swSSL_is_thread_safety() {
+bool swoole_ssl_is_thread_safety() {
     return openssl_thread_safety_init;
 }
 
-static void swSSL_info_callback(const SSL *ssl, int where, int ret) {
+static void swoole_ssl_info_callback(const SSL *ssl, int where, int ret) {
     BIO *rbio, *wbio;
     swSocket *sock;
 
@@ -181,7 +190,7 @@ static void swSSL_info_callback(const SSL *ssl, int where, int ret) {
 
         if (sock->ssl_state == SW_SSL_STATE_READY) {
             sock->ssl_renegotiation = 1;
-            swDebug("SSL renegotiation");
+            swoole_debug("SSL renegotiation");
         }
     }
 
@@ -267,11 +276,11 @@ static int ssl_select_next_proto_cb(SSL *ssl, uchar **out, uchar *outlen, const
     for (unsigned int i = 0; i < inlen; i += in[i] + 1) {
         info += "        * " + std::string(reinterpret_cast<const char *>(&in[i + 1]), in[i]);
     }
-    swTraceLog(SW_TRACE_HTTP2, "[NPN] server offers: %s", info.c_str());
+    swoole_trace_log(SW_TRACE_HTTP2, "[NPN] server offers: %s", info.c_str());
 #endif
     SSLContext *ctx = (SSLContext *) arg;
     if (ctx->http_v2 && !ssl_select_h2(const_cast<const unsigned char**>(out), outlen, in, inlen)) {
-        swWarn("HTTP/2 protocol was not selected, expects [h2]");
+        swoole_warning("HTTP/2 protocol was not selected, expects [h2]");
         return SSL_TLSEXT_ERR_NOACK;
     } else if (ctx->http) {
         *out = (uchar*) HTTP1_NPN.c_str();
@@ -296,7 +305,7 @@ static int ssl_passwd_callback(char *buf, int num, int verify, void *data) {
 
 bool SSLContext::create() {
     if (!openssl_init) {
-        swSSL_init();
+        swoole_ssl_init();
     }
 
     const SSL_METHOD *method;
@@ -314,7 +323,7 @@ bool SSLContext::create() {
     context = SSL_CTX_new(method);
     if (context == nullptr) {
         int error = ERR_get_error();
-        swWarn("SSL_CTX_new() failed, Error: %s[%d]", ERR_reason_error_string(error), error);
+        swoole_warning("SSL_CTX_new() failed, Error: %s[%d]", ERR_reason_error_string(error), error);
         return false;
     }
 
@@ -410,7 +419,7 @@ bool SSLContext::create() {
 #endif
 
     SSL_CTX_set_read_ahead(context, 1);
-    SSL_CTX_set_info_callback(context, swSSL_info_callback);
+    SSL_CTX_set_info_callback(context, swoole_ssl_info_callback);
 
     if (!passphrase.empty()) {
         SSL_CTX_set_default_passwd_cb_userdata(context, this);
@@ -423,7 +432,7 @@ bool SSLContext::create() {
          */
         if (SSL_CTX_use_certificate_file(context, cert_file.c_str(), SSL_FILETYPE_PEM) <= 0) {
             int error = ERR_get_error();
-            swWarn("SSL_CTX_use_certificate_file(%s) failed, Error: %s[%d]", cert_file.c_str(),
+            swoole_warning("SSL_CTX_use_certificate_file(%s) failed, Error: %s[%d]", cert_file.c_str(),
                    ERR_reason_error_string(error), error);
             return true;
         }
@@ -433,7 +442,7 @@ bool SSLContext::create() {
          */
         if (SSL_CTX_use_certificate_chain_file(context, cert_file.c_str()) <= 0) {
             int error = ERR_get_error();
-            swWarn("SSL_CTX_use_certificate_chain_file(%s) failed, Error: %s[%d]", cert_file.c_str(),
+            swoole_warning("SSL_CTX_use_certificate_chain_file(%s) failed, Error: %s[%d]", cert_file.c_str(),
                    ERR_reason_error_string(error), error);
             return false;
         }
@@ -444,7 +453,7 @@ bool SSLContext::create() {
          */
         if (SSL_CTX_use_PrivateKey_file(context, key_file.c_str(), SSL_FILETYPE_PEM) <= 0) {
             int error = ERR_get_error();
-            swWarn("SSL_CTX_use_PrivateKey_file(%s) failed, Error: %s[%d]", key_file.c_str(),
+            swoole_warning("SSL_CTX_use_PrivateKey_file(%s) failed, Error: %s[%d]", key_file.c_str(),
                    ERR_reason_error_string(error), error);
             return false;
         }
@@ -452,15 +461,15 @@ bool SSLContext::create() {
          * verify private key
          */
         if (!SSL_CTX_check_private_key(context)) {
-            swWarn("Private key does not match the public certificate");
+            swoole_warning("Private key does not match the public certificate");
             return false;
         }
     }
 
 #ifdef SW_SUPPORT_DTLS
     if (protocols & SW_SSL_DTLS) {
-        SSL_CTX_set_cookie_generate_cb(context, swSSL_generate_cookie);
-        SSL_CTX_set_cookie_verify_cb(context, swSSL_verify_cookie);
+        SSL_CTX_set_cookie_generate_cb(context, swoole_ssl_generate_cookie);
+        SSL_CTX_set_cookie_verify_cb(context, swoole_ssl_verify_cookie);
     }
 #endif
 
@@ -496,12 +505,12 @@ bool SSLContext::create() {
 #endif
 
     if (!client_cert_file.empty() && !set_client_certificate()) {
-        swWarn("set_client_certificate() error");
+        swoole_warning("set_client_certificate() error");
         return false;
     }
 
     if (!set_ciphers()) {
-        swWarn("set_cipher() error");
+        swoole_warning("set_cipher() error");
         return false;
     }
 
@@ -517,7 +526,7 @@ bool SSLContext::set_capath() {
         }
     } else {
         if (!SSL_CTX_set_default_verify_paths(context)) {
-            swWarn("Unable to set default verify locations and no CA settings specified");
+            swoole_warning("Unable to set default verify locations and no CA settings specified");
             return false;
         }
     }
@@ -536,7 +545,7 @@ bool SSLContext::set_ciphers() {
 
     if (!ciphers.empty()) {
         if (SSL_CTX_set_cipher_list(context, ciphers.c_str()) == 0) {
-            swWarn("SSL_CTX_set_cipher_list(\"%s\") failed", ciphers.c_str());
+            swoole_warning("SSL_CTX_set_cipher_list(\"%s\") failed", ciphers.c_str());
             return false;
         }
         if (prefer_server_ciphers) {
@@ -545,7 +554,7 @@ bool SSLContext::set_ciphers() {
     }
 
 #ifndef OPENSSL_NO_RSA
-    SSL_CTX_set_tmp_rsa_callback(context, swSSL_rsa_key_callback);
+    SSL_CTX_set_tmp_rsa_callback(context, swoole_ssl_rsa_key_callback);
 #endif
 
     if (!dhparam.empty() && !set_dhparam()) {
@@ -553,7 +562,7 @@ bool SSLContext::set_ciphers() {
     }
 #if OPENSSL_VERSION_NUMBER < 0x10100000L
     else {
-        swSSL_set_default_dhparam(context);
+        swoole_ssl_set_default_dhparam(context);
     }
 #endif
     if (!ecdh_curve.empty() && !set_ecdh_curve()) {
@@ -568,18 +577,18 @@ bool SSLContext::set_client_certificate() {
     const char *cert_file = client_cert_file.c_str();
     int depth = verify_depth;
 
-    SSL_CTX_set_verify(context, SSL_VERIFY_PEER, swSSL_verify_callback);
+    SSL_CTX_set_verify(context, SSL_VERIFY_PEER, swoole_ssl_verify_callback);
     SSL_CTX_set_verify_depth(context, depth);
 
     if (SSL_CTX_load_verify_locations(context, cert_file, nullptr) == 0) {
-        swWarn("SSL_CTX_load_verify_locations(\"%s\") failed", cert_file);
+        swoole_warning("SSL_CTX_load_verify_locations(\"%s\") failed", cert_file);
         return false;
     }
 
     ERR_clear_error();
     list = SSL_load_client_CA_file(cert_file);
     if (list == nullptr) {
-        swWarn("SSL_load_client_CA_file(\"%s\") failed", cert_file);
+        swoole_warning("SSL_load_client_CA_file(\"%s\") failed", cert_file);
         return false;
     }
 
@@ -618,7 +627,7 @@ bool SSLContext::set_ecdh_curve() {
         return true;
     }
     if (SSL_CTX_set1_curves_list(context, ecdh_curve.c_str()) == 0) {
-        swWarn("SSL_CTX_set1_curves_list(\"%s\") failed", ecdh_curve.c_str());
+        swoole_warning("SSL_CTX_set1_curves_list(\"%s\") failed", ecdh_curve.c_str());
         return false;
     }
 #else
@@ -631,13 +640,13 @@ bool SSLContext::set_ecdh_curve() {
      */
     int nid = OBJ_sn2nid(ecdh_curve.c_str());
     if (nid == 0) {
-        swWarn("Unknown curve name \"%s\"", ecdh_curve.c_str());
+        swoole_warning("Unknown curve name \"%s\"", ecdh_curve.c_str());
         return false;
     }
 
     ecdh = EC_KEY_new_by_curve_name(nid);
     if (ecdh == nullptr) {
-        swWarn("Unable to create curve \"%s\"", ecdh_curve.c_str());
+        swoole_warning("Unable to create curve \"%s\"", ecdh_curve.c_str());
         return false;
     }
 
@@ -659,13 +668,13 @@ bool SSLContext::set_dhparam() {
 
     bio = BIO_new_file(file, "r");
     if (bio == nullptr) {
-        swWarn("BIO_new_file(%s) failed", file);
+        swoole_warning("BIO_new_file(%s) failed", file);
         return false;
     }
 
     dh = PEM_read_bio_DHparams(bio, nullptr, nullptr, nullptr);
     if (dh == nullptr) {
-        swWarn("PEM_read_bio_DHparams(%s) failed", file);
+        swoole_warning("PEM_read_bio_DHparams(%s) failed", file);
         BIO_free(bio);
         return false;
     }
@@ -684,7 +693,7 @@ SSLContext::~SSLContext() {
 
 }
 
-static int swSSL_verify_callback(int ok, X509_STORE_CTX *x509_store) {
+static int swoole_ssl_verify_callback(int ok, X509_STORE_CTX *x509_store) {
 #if 0
     char *subject, *issuer;
     int err, depth;
@@ -700,7 +709,7 @@ static int swSSL_verify_callback(int ok, X509_STORE_CTX *x509_store) {
 
     iname = X509_get_issuer_name(cert);
     issuer = iname ? X509_NAME_oneline(iname, nullptr, 0) : "(none)";
-    swWarn("verify:%d, error:%d, depth:%d, subject:\"%s\", issuer:\"%s\"", ok, err, depth, subject, issuer);
+    swoole_warning("verify:%d, error:%d, depth:%d, subject:\"%s\", issuer:\"%s\"", ok, err, depth, subject, issuer);
 
     if (sname)
     {
@@ -729,7 +738,7 @@ static void calculate_cookie(SSL *ssl, uchar *cookie_secret, uint cookie_length)
     }
 }
 
-static int swSSL_generate_cookie(SSL *ssl, uchar *cookie, uint *cookie_len) {
+static int swoole_ssl_generate_cookie(SSL *ssl, uchar *cookie, uint *cookie_len) {
     uchar *buffer, result[EVP_MAX_MD_SIZE];
     uint length = 0, result_len;
     Address sa{};
@@ -757,7 +766,7 @@ static int swSSL_generate_cookie(SSL *ssl, uchar *cookie, uint *cookie_len) {
     buffer = (uchar *) OPENSSL_malloc(length);
 
     if (buffer == nullptr) {
-        swSysWarn("out of memory");
+        swoole_sys_warning("out of memory");
         return 0;
     }
 
@@ -784,18 +793,18 @@ static int swSSL_generate_cookie(SSL *ssl, uchar *cookie, uint *cookie_len) {
     return 1;
 }
 
-static int swSSL_verify_cookie(SSL *ssl, const uchar *cookie, uint cookie_len) {
+static int swoole_ssl_verify_cookie(SSL *ssl, const uchar *cookie, uint cookie_len) {
     uint result_len = 0;
     uchar result[COOKIE_SECRET_LENGTH];
 
-    swSSL_generate_cookie(ssl, result, &result_len);
+    swoole_ssl_generate_cookie(ssl, result, &result_len);
 
     return cookie_len == result_len && memcmp(result, cookie, result_len) == 0;
 }
 #endif
 
 #ifndef OPENSSL_NO_RSA
-static RSA *swSSL_rsa_key_callback(SSL *ssl, int is_export, int key_length) {
+static RSA *swoole_ssl_rsa_key_callback(SSL *ssl, int is_export, int key_length) {
     static RSA *rsa_tmp = nullptr;
     if (rsa_tmp) {
         return rsa_tmp;
@@ -803,7 +812,7 @@ static RSA *swSSL_rsa_key_callback(SSL *ssl, int is_export, int key_length) {
 
     BIGNUM *bn = BN_new();
     if (bn == nullptr) {
-        swWarn("allocation error generating RSA key");
+        swoole_warning("allocation error generating RSA key");
         return nullptr;
     }
 
@@ -820,7 +829,7 @@ static RSA *swSSL_rsa_key_callback(SSL *ssl, int is_export, int key_length) {
 #endif
 
 #if OPENSSL_VERSION_NUMBER < 0x10100000L
-static int swSSL_set_default_dhparam(SSL_CTX *ssl_context) {
+static int swoole_ssl_set_default_dhparam(SSL_CTX *ssl_context) {
     DH *dh;
     static unsigned char dh1024_p[] = {
         0xBB, 0xBC, 0x2D, 0xCA, 0xD8, 0x46, 0x74, 0x90, 0x7C, 0x43, 0xFC, 0xF5, 0x80, 0xE9, 0xCF, 0xDB,
@@ -835,7 +844,7 @@ static int swSSL_set_default_dhparam(SSL_CTX *ssl_context) {
     static unsigned char dh1024_g[] = {0x02};
     dh = DH_new();
     if (dh == nullptr) {
-        swWarn("DH_new() failed");
+        swoole_warning("DH_new() failed");
         return SW_ERR;
     }
 
