@@ -82,7 +82,7 @@ ReactorImpl *make_reactor_epoll(Reactor *_reactor, int max_events) {
 ReactorEpoll::ReactorEpoll(Reactor *_reactor, int max_events) : ReactorImpl(_reactor) {
     epfd_ = epoll_create(512);
     if (!ready()) {
-        swSysWarn("epoll_create failed");
+        swoole_sys_warning("epoll_create failed");
         return;
     }
 
@@ -109,7 +109,7 @@ int ReactorEpoll::add(Socket *socket, int events) {
     e.data.ptr = socket;
 
     if (epoll_ctl(epfd_, EPOLL_CTL_ADD, socket->fd, &e) < 0) {
-        swSysWarn(
+        swoole_sys_warning(
             "failed to add events[fd=%d#%d, type=%d, events=%d]", socket->fd, reactor_->id, socket->fd_type, events);
         return SW_ERR;
     }
@@ -119,7 +119,7 @@ int ReactorEpoll::add(Socket *socket, int events) {
 #endif
 
     reactor_->_add(socket, events);
-    swTraceLog(
+    swoole_trace_log(
         SW_TRACE_EVENT, "add events[fd=%d#%d, type=%d, events=%d]", socket->fd, reactor_->id, socket->fd_type, events);
 
     return SW_OK;
@@ -144,7 +144,7 @@ int ReactorEpoll::del(Socket *_socket) {
     event_map.erase(_socket->fd);
 #endif
 
-    swTraceLog(SW_TRACE_REACTOR, "remove event[reactor_id=%d|fd=%d]", reactor_->id, _socket->fd);
+    swoole_trace_log(SW_TRACE_REACTOR, "remove event[reactor_id=%d|fd=%d]", reactor_->id, _socket->fd);
     reactor_->_del(_socket);
 
     return SW_OK;
@@ -158,12 +158,12 @@ int ReactorEpoll::set(Socket *socket, int events) {
 
     int ret = epoll_ctl(epfd_, EPOLL_CTL_MOD, socket->fd, &e);
     if (ret < 0) {
-        swSysWarn(
+        swoole_sys_warning(
             "failed to set events[fd=%d#%d, type=%d, events=%d]", socket->fd, reactor_->id, socket->fd_type, events);
         return SW_ERR;
     }
 
-    swTraceLog(SW_TRACE_EVENT, "set event[reactor_id=%d, fd=%d, events=%d]", reactor_->id, socket->fd, events);
+    swoole_trace_log(SW_TRACE_EVENT, "set event[reactor_id=%d, fd=%d, events=%d]", reactor_->id, socket->fd, events);
     reactor_->_set(socket, events);
 
     return SW_OK;
@@ -194,7 +194,7 @@ int ReactorEpoll::wait(struct timeval *timeo) {
         n = epoll_wait(epfd_, events_, max_event_num, reactor_->get_timeout_msec());
         if (n < 0) {
             if (!reactor_->catch_error()) {
-                swSysWarn("[Reactor#%d] epoll_wait failed", reactor_id);
+                swoole_sys_warning("[Reactor#%d] epoll_wait failed", reactor_id);
                 return SW_ERR;
             } else {
                 goto _continue;
@@ -217,7 +217,7 @@ int ReactorEpoll::wait(struct timeval *timeo) {
                 handler = reactor_->get_handler(SW_EVENT_READ, event.type);
                 ret = handler(reactor_, &event);
                 if (ret < 0) {
-                    swSysWarn("EPOLLIN handle failed. fd=%d", event.fd);
+                    swoole_sys_warning("EPOLLIN handle failed. fd=%d", event.fd);
                 }
             }
             // write
@@ -225,7 +225,7 @@ int ReactorEpoll::wait(struct timeval *timeo) {
                 handler = reactor_->get_handler(SW_EVENT_WRITE, event.type);
                 ret = handler(reactor_, &event);
                 if (ret < 0) {
-                    swSysWarn("EPOLLOUT handle failed. fd=%d", event.fd);
+                    swoole_sys_warning("EPOLLOUT handle failed. fd=%d", event.fd);
                 }
             }
             // error
@@ -237,7 +237,7 @@ int ReactorEpoll::wait(struct timeval *timeo) {
                 handler = reactor_->get_error_handler(event.type);
                 ret = handler(reactor_, &event);
                 if (ret < 0) {
-                    swSysWarn("EPOLLERR handle failed. fd=%d", event.fd);
+                    swoole_sys_warning("EPOLLERR handle failed. fd=%d", event.fd);
                 }
             }
             if (!event.socket->removed && (event.socket->events & SW_EVENT_ONCE)) {
