@@ -22,8 +22,8 @@
 #include "swoole_redis.h"
 
 using swoole::http_server::Request;
-using swoole::network::Socket;
 using swoole::network::Address;
+using swoole::network::Socket;
 
 namespace swoole {
 
@@ -81,7 +81,7 @@ static bool ssl_matches_wildcard_name(const char *subjectname, const char *certn
          * 3) no . between prefix and suffix
          **/
         return strcasecmp(wildcard + 1, subjectname + subject_len - suffix_len) == 0 &&
-            memchr(subjectname + prefix_len, '.', subject_len - suffix_len - prefix_len) == NULL;
+               memchr(subjectname + prefix_len, '.', subject_len - suffix_len - prefix_len) == NULL;
     }
 
     return 0;
@@ -93,7 +93,7 @@ static int ssl_server_sni_callback(SSL *ssl, int *al, void *arg) {
         return SSL_TLSEXT_ERR_NOACK;
     }
 
-    ListenPort *port = (ListenPort *) SSL_get_ex_data(ssl, swSSL_get_ex_port_index());
+    ListenPort *port = (ListenPort *) SSL_get_ex_data(ssl, swoole_ssl_get_ex_port_index());
 
     if (port->sni_contexts.empty()) {
         return SSL_TLSEXT_ERR_NOACK;
@@ -124,8 +124,8 @@ bool ListenPort::ssl_create(Connection *conn, Socket *sock) {
         return false;
     }
     conn->ssl = 1;
-    if (SSL_set_ex_data(sock->ssl, swSSL_get_ex_port_index(), this) == 0) {
-        swWarn("SSL_set_ex_data() failed");
+    if (SSL_set_ex_data(sock->ssl, swoole_ssl_get_ex_port_index(), this) == 0) {
+        swoole_warning("SSL_set_ex_data() failed");
         return false;
     }
     return true;
@@ -133,7 +133,7 @@ bool ListenPort::ssl_create(Connection *conn, Socket *sock) {
 
 bool ListenPort::ssl_create_context(SSLContext *context) {
     if (context->cert_file.empty() || context->key_file.empty()) {
-        swWarn("SSL error, require ssl_cert_file and ssl_key_file");
+        swoole_warning("SSL error, require ssl_cert_file and ssl_key_file");
         return false;
     }
     if (open_http_protocol) {
@@ -143,7 +143,7 @@ bool ListenPort::ssl_create_context(SSLContext *context) {
         context->http_v2 = 1;
     }
     if (!context->create()) {
-        swWarn("swSSL_get_context() error");
+        swoole_warning("swSSL_get_context() error");
         return false;
     }
     return true;
@@ -153,7 +153,7 @@ bool ListenPort::ssl_create_context(SSLContext *context) {
 int ListenPort::listen() {
     // listen stream socket
     if (!listening && socket->listen(backlog) < 0) {
-        swSysWarn("listen(%s:%d, %d) failed", host.c_str(), port, backlog);
+        swoole_sys_warning("listen(%s:%d, %d) failed", host.c_str(), port, backlog);
         return SW_ERR;
     }
     listening = true;
@@ -161,7 +161,7 @@ int ListenPort::listen() {
 #ifdef TCP_DEFER_ACCEPT
     if (tcp_defer_accept) {
         if (socket->set_option(IPPROTO_TCP, TCP_DEFER_ACCEPT, tcp_defer_accept) != 0) {
-            swSysWarn("setsockopt(TCP_DEFER_ACCEPT) failed");
+            swoole_sys_warning("setsockopt(TCP_DEFER_ACCEPT) failed");
         }
     }
 #endif
@@ -172,7 +172,7 @@ int ListenPort::listen() {
         memset(&a, 0, sizeof(a));
         strcpy(a.af_name, "httpready");
         if (socket->set_option(SOL_SOCKET, SO_ACCEPTFILTER, &a, sizeof(a)) != 0) {
-            swSysWarn("setsockopt(SO_ACCEPTFILTER) failed");
+            swoole_sys_warning("setsockopt(SO_ACCEPTFILTER) failed");
         }
     }
 #endif
@@ -180,7 +180,7 @@ int ListenPort::listen() {
 #ifdef TCP_FASTOPEN
     if (tcp_fastopen) {
         if (socket->set_option(IPPROTO_TCP, TCP_FASTOPEN, tcp_fastopen) != 0) {
-            swSysWarn("setsockopt(TCP_FASTOPEN) failed");
+            swoole_sys_warning("setsockopt(TCP_FASTOPEN) failed");
         }
     }
 #endif
@@ -188,22 +188,22 @@ int ListenPort::listen() {
 #ifdef SO_KEEPALIVE
     if (open_tcp_keepalive == 1) {
         if (socket->set_option(SOL_SOCKET, SO_KEEPALIVE, 1) != 0) {
-            swSysWarn("setsockopt(SO_KEEPALIVE) failed");
+            swoole_sys_warning("setsockopt(SO_KEEPALIVE) failed");
         }
 #ifdef TCP_KEEPIDLE
         if (socket->set_option(IPPROTO_TCP, TCP_KEEPIDLE, tcp_keepidle) < 0) {
-            swSysWarn("setsockopt(TCP_KEEPIDLE) failed");
+            swoole_sys_warning("setsockopt(TCP_KEEPIDLE) failed");
         }
         if (socket->set_option(IPPROTO_TCP, TCP_KEEPINTVL, tcp_keepinterval) < 0) {
-            swSysWarn("setsockopt(TCP_KEEPINTVL) failed");
+            swoole_sys_warning("setsockopt(TCP_KEEPINTVL) failed");
         }
         if (socket->set_option(IPPROTO_TCP, TCP_KEEPCNT, tcp_keepcount) < 0) {
-            swSysWarn("setsockopt(TCP_KEEPCNT) failed");
+            swoole_sys_warning("setsockopt(TCP_KEEPCNT) failed");
         }
 #endif
 #ifdef TCP_USER_TIMEOUT
         if (tcp_user_timeout > 0 && socket->set_option(IPPROTO_TCP, TCP_USER_TIMEOUT, tcp_user_timeout) != 0) {
-            swSysWarn("setsockopt(TCP_USER_TIMEOUT) failed");
+            swoole_sys_warning("setsockopt(TCP_USER_TIMEOUT) failed");
         }
 #endif
     }
@@ -234,25 +234,25 @@ void Server::init_port_protocol(ListenPort *ls) {
     } else if (ls->open_http_protocol) {
 #ifdef SW_USE_HTTP2
         if (ls->open_http2_protocol && ls->open_websocket_protocol) {
-            ls->protocol.get_package_length = swHttpMix_get_package_length;
-            ls->protocol.get_package_length_size = swHttpMix_get_package_length_size;
-            ls->protocol.onPackage = swHttpMix_dispatch_frame;
+            ls->protocol.get_package_length = http_server::get_package_length;
+            ls->protocol.get_package_length_size = http_server::get_package_length_size;
+            ls->protocol.onPackage = http_server::dispatch_frame;
         } else if (ls->open_http2_protocol) {
             ls->protocol.package_length_size = SW_HTTP2_FRAME_HEADER_SIZE;
-            ls->protocol.get_package_length = swHttp2_get_frame_length;
+            ls->protocol.get_package_length = http2::get_frame_length;
             ls->protocol.onPackage = Server::dispatch_task;
         } else
 #endif
             if (ls->open_websocket_protocol) {
             ls->protocol.package_length_size = SW_WEBSOCKET_HEADER_LEN + SW_WEBSOCKET_MASK_LEN + sizeof(uint64_t);
-            ls->protocol.get_package_length = swWebSocket_get_package_length;
-            ls->protocol.onPackage = swWebSocket_dispatch_frame;
+            ls->protocol.get_package_length = websocket::get_package_length;
+            ls->protocol.onPackage = websocket::dispatch_frame;
         }
         ls->protocol.package_length_offset = 0;
         ls->protocol.package_body_offset = 0;
         ls->onRead = Port_onRead_http;
     } else if (ls->open_mqtt_protocol) {
-        swMqtt_set_protocol(&ls->protocol);
+        mqtt::set_protocol(&ls->protocol);
         ls->protocol.onPackage = Server::dispatch_task;
         ls->onRead = Port_onRead_check_length;
     } else if (ls->open_redis_protocol) {
@@ -271,14 +271,14 @@ bool ListenPort::import(int sock) {
 
     socket = new Socket();
     socket->fd = sock;
-    
+
     // get socket type
     if (socket->get_option(SOL_SOCKET, SO_TYPE, &_type) < 0) {
-        swSysWarn("getsockopt(%d, SOL_SOCKET, SO_TYPE) failed", sock);
+        swoole_sys_warning("getsockopt(%d, SOL_SOCKET, SO_TYPE) failed", sock);
         return false;
     }
     if (socket->get_name(&socket->info) < 0) {
-        swSysWarn("getsockname(%d) failed", sock);
+        swoole_sys_warning("getsockname(%d) failed", sock);
         return false;
     }
 
@@ -321,7 +321,7 @@ static int Port_onRead_raw(Reactor *reactor, ListenPort *port, Event *event) {
     if (n < 0) {
         switch (_socket->catch_error(errno)) {
         case SW_ERROR:
-            swSysWarn("recv from connection#%d failed", event->fd);
+            swoole_sys_warning("recv from connection#%d failed", event->fd);
             return SW_OK;
         case SW_CLOSE:
             conn->close_errno = errno;
@@ -352,7 +352,7 @@ static int Port_onRead_check_length(Reactor *reactor, ListenPort *port, Event *e
     }
 
     if (protocol->recv_with_length_protocol(_socket, buffer) < 0) {
-        swTrace("Close Event.FD=%d|From=%d", event->fd, event->reactor_id);
+        swoole_trace("Close Event.FD=%d|From=%d", event->fd, event->reactor_id);
         conn->close_errno = errno;
         reactor->trigger_close_event(event);
     }
@@ -380,10 +380,10 @@ static int Port_onRead_http(Reactor *reactor, ListenPort *port, Event *event) {
     Connection *conn = (Connection *) _socket->object;
     Server *serv = (Server *) reactor->ptr;
 
-    if (conn->websocket_status >= WEBSOCKET_STATUS_HANDSHAKE) {
+    if (conn->websocket_status >= websocket::STATUS_HANDSHAKE) {
         if (conn->http_upgrade == 0) {
             serv->destroy_http_request(conn);
-            conn->websocket_status = WEBSOCKET_STATUS_ACTIVE;
+            conn->websocket_status = websocket::STATUS_ACTIVE;
             conn->http_upgrade = 1;
         }
         return Port_onRead_check_length(reactor, port, event);
@@ -420,7 +420,7 @@ _recv_data:
     if (n < 0) {
         switch (_socket->catch_error(errno)) {
         case SW_ERROR:
-            swSysWarn("recv from connection#%d failed", event->fd);
+            swoole_sys_warning("recv from connection#%d failed", event->fd);
             return SW_OK;
         case SW_CLOSE:
             conn->close_errno = errno;
@@ -487,7 +487,7 @@ _parse:
 #ifdef SW_USE_HTTP2
         }
         conn->http2_stream = 1;
-        swHttp2_send_setting_frame(protocol, _socket);
+        http2::send_setting_frame(protocol, _socket);
         if (buffer->length == sizeof(SW_HTTP2_PRI_STRING) - 1) {
             serv->destroy_http_request(conn);
             buffer->clear();
@@ -517,7 +517,7 @@ _parse:
     // parse http header and got http body length
     if (!request->header_parsed) {
         request->parse_header_info();
-        swTraceLog(SW_TRACE_SERVER,
+        swoole_trace_log(SW_TRACE_SERVER,
                    "content-length=%u, keep-alive=%u, chunked=%u",
                    request->content_length_,
                    request->keep_alive,
@@ -589,7 +589,7 @@ _parse:
         } else {
             request_length = request->header_length_ + request->content_length_;
         }
-        swTraceLog(SW_TRACE_SERVER, "received chunked eof, real content-length=%u", request->content_length_);
+        swoole_trace_log(SW_TRACE_SERVER, "received chunked eof, real content-length=%u", request->content_length_);
     } else {
         request_length = request->header_length_ + request->content_length_;
         if (request_length > protocol->package_max_length) {
@@ -614,7 +614,7 @@ _parse:
             if (request->has_expect_header()) {
                 _socket->send(SW_STRL(SW_HTTP_100_CONTINUE_PACKET), 0);
             } else {
-                swTraceLog(SW_TRACE_SERVER,
+                swoole_trace_log(SW_TRACE_SERVER,
                            "PostWait: request->content_length=%d, buffer->length=%zu, request->header_length=%d\n",
                            request->content_length,
                            buffer_->length,
@@ -663,7 +663,7 @@ static int Port_onRead_redis(Reactor *reactor, ListenPort *port, Event *event) {
         return SW_ERR;
     }
 
-    if (swRedis_recv_packet(protocol, conn, buffer) < 0) {
+    if (redis::recv_packet(protocol, conn, buffer) < 0) {
         conn->close_errno = errno;
         reactor->trigger_close_event(event);
     }
@@ -723,4 +723,4 @@ void ListenPort::close() {
     }
 }
 
-}
+}  // namespace swoole
