@@ -36,11 +36,11 @@ bool ProcessFactory::shutdown() {
     int status;
 
     if (swoole_kill(server_->gs->manager_pid, SIGTERM) < 0) {
-        swSysWarn("swKill(%d) failed", server_->gs->manager_pid);
+        swoole_sys_warning("swKill(%d) failed", server_->gs->manager_pid);
     }
 
     if (swoole_waitpid(server_->gs->manager_pid, &status, 0) < 0) {
-        swSysWarn("waitpid(%d) failed", server_->gs->manager_pid);
+        swoole_sys_warning("waitpid(%d) failed", server_->gs->manager_pid);
     }
 
     SW_LOOP_N(server_->worker_num) {
@@ -69,7 +69,7 @@ ProcessFactory::~ProcessFactory() {
 }
 
 bool ProcessFactory::start() {
-    if (server_->dispatch_mode == SW_DISPATCH_STREAM) {
+    if (server_->dispatch_mode == Server::DISPATCH_STREAM) {
         server_->stream_socket_file = swoole_string_format(64, "/tmp/swoole.%d.sock", server_->gs->master_pid);
         if (server_->stream_socket_file == nullptr) {
             return false;
@@ -112,7 +112,7 @@ bool ProcessFactory::start() {
 
     send_buffer = (PipeBuffer *) sw_malloc(server_->ipc_max_size);
     if (send_buffer == nullptr) {
-        swSysError("malloc[send_buffer] failed");
+        swoole_sys_error("malloc[send_buffer] failed");
         return false;
     }
     sw_memset_zero(send_buffer, sizeof(DataHead));
@@ -121,7 +121,7 @@ bool ProcessFactory::start() {
      * The manager process must be started first, otherwise it will have a thread fork
      */
     if (server_->start_manager_process() < 0) {
-        swWarn("FactoryProcess_manager_start failed");
+        swoole_warning("FactoryProcess_manager_start failed");
         return false;
     }
     return true;
@@ -137,11 +137,13 @@ bool ProcessFactory::notify(DataHead *ev) {
     return dispatch(&task);
 }
 
-static inline int process_sendto_worker(Server *serv, DataHead *head, const iovec *iov, size_t iovcnt, void *private_data) {
+static inline int process_sendto_worker(
+    Server *serv, DataHead *head, const iovec *iov, size_t iovcnt, void *private_data) {
     return serv->send_to_worker_from_master((Worker *) private_data, iov, iovcnt);
 }
 
-static inline int process_sendto_reactor(Server *serv, DataHead *head, const iovec *iov, size_t iovcnt, void *private_data) {
+static inline int process_sendto_reactor(
+    Server *serv, DataHead *head, const iovec *iov, size_t iovcnt, void *private_data) {
     return serv->send_to_reactor_thread(head, iov, iovcnt, ((Connection *) private_data)->session_id);
 }
 
@@ -154,13 +156,13 @@ bool ProcessFactory::dispatch(SendData *task) {
     int target_worker_id = server_->schedule_worker(fd, task);
     if (target_worker_id < 0) {
         switch (target_worker_id) {
-        case SW_DISPATCH_RESULT_DISCARD_PACKET:
+        case Server::DISPATCH_RESULT_DISCARD_PACKET:
             return false;
-        case SW_DISPATCH_RESULT_CLOSE_CONNECTION:
+        case Server::DISPATCH_RESULT_CLOSE_CONNECTION:
             // TODO: close connection
             return false;
         default:
-            swWarn("invalid target worker id[%d]", target_worker_id);
+            swoole_warning("invalid target worker id[%d]", target_worker_id);
             return false;
         }
     }
@@ -168,7 +170,7 @@ bool ProcessFactory::dispatch(SendData *task) {
     if (Server::is_stream_event(task->info.type)) {
         Connection *conn = server_->get_connection(fd);
         if (conn == nullptr || conn->active == 0) {
-            swWarn("dispatch[type=%d] failed, connection#%d is not active", task->info.type, fd);
+            swoole_warning("dispatch[type=%d] failed, connection#%d is not active", task->info.type, fd);
             return false;
         }
         // server active close, discard data.
@@ -203,7 +205,7 @@ bool ProcessFactory::dispatch(SendData *task) {
  */
 static bool process_send_packet(Server *serv, SendData *resp, SendFunc _send, void *private_data) {
     const char *data = resp->data;
-    uint32_t send_n = resp->info.len;
+    uint32_t l_payload = resp->info.len;
     off_t offset = 0;
     uint32_t copy_n;
 
@@ -212,17 +214,17 @@ static bool process_send_packet(Server *serv, SendData *resp, SendFunc _send, vo
     uint32_t max_length = serv->ipc_max_size - sizeof(resp->info);
     resp->info.msg_id = serv->worker_msg_id.fetch_add(1);
 
-    if (send_n <= max_length) {
+    if (l_payload <= max_length) {
         resp->info.flags = 0;
-        resp->info.len = send_n;
+        resp->info.len = l_payload;
 
         size_t iovcnt;
         iov[0].iov_base = &resp->info;
         iov[0].iov_len = sizeof(resp->info);
 
-        if (resp->data) {
+        if (resp->data && l_payload > 0) {
             iov[1].iov_base = (void *) resp->data;
-            iov[1].iov_len = send_n;
+            iov[1].iov_len = l_payload;
             iovcnt = 2;
         } else {
             iovcnt = 1;
@@ -242,14 +244,14 @@ static bool process_send_packet(Server *serv, SendData *resp, SendFunc _send, vo
 _ipc_use_chunk:
 #endif
     resp->info.flags = SW_EVENT_DATA_CHUNK | SW_EVENT_DATA_BEGIN;
-    resp->info.len = send_n;
+    resp->info.len = l_payload;
 
-    while (send_n > 0) {
-        if (send_n > max_length) {
+    while (l_payload > 0) {
+        if (l_payload > max_length) {
             copy_n = max_length;
         } else {
             resp->info.flags |= SW_EVENT_DATA_END;
-            copy_n = send_n;
+            copy_n = l_payload;
         }
 
         iov[0].iov_base = &resp->info;
@@ -257,7 +259,7 @@ _ipc_use_chunk:
         iov[1].iov_base = (void *) (data + offset);
         iov[1].iov_len = copy_n;
 
-        swTrace("finish, type=%d|len=%u", resp->info.type, copy_n);
+        swoole_trace("finish, type=%d|len=%u", resp->info.type, copy_n);
 
         if (_send(serv, &resp->info, iov, 2, private_data) < 0) {
 #ifdef __linux__
@@ -273,7 +275,7 @@ _ipc_use_chunk:
             resp->info.flags &= ~SW_EVENT_DATA_BEGIN;
         }
 
-        send_n -= copy_n;
+        l_payload -= copy_n;
         offset += copy_n;
     }
 
@@ -358,7 +360,7 @@ bool ProcessFactory::finish(SendData *resp) {
     task.info.reactor_id = conn->reactor_id;
     task.info.server_fd = SwooleG.process_id;
 
-    swTrace("worker_id=%d, type=%d", SwooleG.process_id, task.info.type);
+    swoole_trace("worker_id=%d, type=%d", SwooleG.process_id, task.info.type);
 
     return process_send_packet(server_, &task, process_sendto_reactor, conn);
 }
@@ -385,7 +387,7 @@ bool ProcessFactory::end(SessionId session_id, int flags) {
         conn->close_actively = 1;
     }
 
-    swTraceLog(SW_TRACE_CLOSE, "session_id=%ld, fd=%d", session_id, conn->fd);
+    swoole_trace_log(SW_TRACE_CLOSE, "session_id=%ld, fd=%d", session_id, conn->fd);
 
     Worker *worker;
     DataHead ev = {};
@@ -416,7 +418,7 @@ bool ProcessFactory::end(SessionId session_id, int flags) {
         }
     }
 
-    _close:
+_close:
     if (conn == nullptr || conn->active == 0) {
         swoole_set_last_error(SW_ERROR_SESSION_NOT_EXIST);
         return false;
