@@ -23,6 +23,7 @@
 #include "swoole_memory.h"
 #include "swoole_msg_queue.h"
 #include "swoole_client.h"
+#include "swoole_coroutine.h"
 
 swoole::WorkerGlobal SwooleWG = {};
 
@@ -42,16 +43,16 @@ void Server::worker_signal_init(void) {
      */
     SwooleG.use_signalfd = SwooleG.enable_signalfd;
 
-    swSignal_set(SIGHUP, nullptr);
-    swSignal_set(SIGPIPE, SIG_IGN);
-    swSignal_set(SIGUSR1, nullptr);
-    swSignal_set(SIGUSR2, nullptr);
+    swoole_signal_set(SIGHUP, nullptr);
+    swoole_signal_set(SIGPIPE, SIG_IGN);
+    swoole_signal_set(SIGUSR1, nullptr);
+    swoole_signal_set(SIGUSR2, nullptr);
     // swSignal_set(SIGINT, Server::worker_signal_handler);
-    swSignal_set(SIGTERM, Server::worker_signal_handler);
+    swoole_signal_set(SIGTERM, Server::worker_signal_handler);
     // for test
-    swSignal_set(SIGVTALRM, Server::worker_signal_handler);
+    swoole_signal_set(SIGVTALRM, Server::worker_signal_handler);
 #ifdef SIGRTMIN
-    swSignal_set(SIGRTMIN, Server::worker_signal_handler);
+    swoole_signal_set(SIGRTMIN, Server::worker_signal_handler);
 #endif
 }
 
@@ -72,7 +73,7 @@ void Server::worker_signal_handler(int signo) {
         break;
     // for test
     case SIGVTALRM:
-        swWarn("SIGVTALRM coming");
+        swoole_warning("SIGVTALRM coming");
         break;
     case SIGUSR1:
     case SIGUSR2:
@@ -121,7 +122,7 @@ static int Worker_onStreamAccept(Reactor *reactor, Event *event) {
         case EAGAIN:
             return SW_OK;
         default:
-            swSysWarn("accept() failed");
+            swoole_sys_warning("accept() failed");
             return SW_OK;
         }
     }
@@ -227,7 +228,7 @@ int Server::accept_task(EventData *task) {
         if (conn) {
             if (task->info.len > 0) {
                 sw_atomic_fetch_sub(&conn->recv_queued_bytes, task->info.len);
-                swTraceLog(SW_TRACE_SERVER, "[Worker] len=%d, qb=%d\n", task->info.len, conn->recv_queued_bytes);
+                swoole_trace_log(SW_TRACE_SERVER, "[Worker] len=%d, qb=%d\n", task->info.len, conn->recv_queued_bytes);
             }
             conn->last_dispatch_time = task->info.time;
         }
@@ -291,7 +292,7 @@ int Server::accept_task(EventData *task) {
         break;
     }
     default:
-        swWarn("[Worker] error event[type=%d]", (int) task->info.type);
+        swoole_warning("[Worker] error event[type=%d]", (int) task->info.type);
         break;
     }
 
@@ -321,32 +322,32 @@ void Server::worker_start_callback() {
         if (!group_.empty()) {
             _group = getgrnam(group_.c_str());
             if (!_group) {
-                swWarn("get group [%s] info failed", group_.c_str());
+                swoole_warning("get group [%s] info failed", group_.c_str());
             }
         }
         // get user info
         if (!user_.empty()) {
             _passwd = getpwnam(user_.c_str());
             if (!_passwd) {
-                swWarn("get user [%s] info failed", user_.c_str());
+                swoole_warning("get user [%s] info failed", user_.c_str());
             }
         }
         // set process group
         if (_group && setgid(_group->gr_gid) < 0) {
-            swSysWarn("setgid to [%s] failed", group_.c_str());
+            swoole_sys_warning("setgid to [%s] failed", group_.c_str());
         }
         // set process user
         if (_passwd && setuid(_passwd->pw_uid) < 0) {
-            swSysWarn("setuid to [%s] failed", user_.c_str());
+            swoole_sys_warning("setuid to [%s] failed", user_.c_str());
         }
         // chroot
         if (!chroot_.empty()) {
             if (::chroot(chroot_.c_str()) == 0) {
                 if (chdir("/") < 0) {
-                    swSysWarn("chdir(\"/\") failed");
+                    swoole_sys_warning("chdir(\"/\") failed");
                 }
             } else {
-                swSysWarn("chroot(\"%s\") failed", chroot_.c_str());
+                swoole_sys_warning("chroot(\"%s\") failed", chroot_.c_str());
             }
         }
     }
@@ -380,7 +381,7 @@ void Server::worker_start_callback() {
 
 #ifdef HAVE_SIGNALFD
     if (SwooleG.use_signalfd && SwooleTG.reactor && SwooleG.signal_fd == 0) {
-        swSignalfd_setup(SwooleTG.reactor);
+        swoole_signalfd_setup(SwooleTG.reactor);
     }
 #endif
 
@@ -558,7 +559,7 @@ int Server::start_event_worker(Worker *worker) {
     reactor->add(worker->pipe_worker, SW_EVENT_READ);
     reactor->set_handler(SW_FD_PIPE, Worker_onPipeReceive);
 
-    if (dispatch_mode == SW_DISPATCH_STREAM) {
+    if (dispatch_mode == DISPATCH_STREAM) {
         reactor->add(stream_socket, SW_EVENT_READ);
         reactor->set_handler(SW_FD_STREAM_SERVER, Worker_onStreamAccept);
         reactor->set_handler(SW_FD_STREAM, Worker_onStreamRead);
@@ -567,6 +568,9 @@ int Server::start_event_worker(Worker *worker) {
         stream_protocol.package_max_length = UINT_MAX;
         stream_protocol.onPackage = Worker_onStreamPackage;
         buffer_pool = new std::queue<String *>;
+    } else if (dispatch_mode == DISPATCH_CO_CONN_LB || dispatch_mode == DISPATCH_CO_REQ_LB) {
+        reactor->set_end_callback(Reactor::PRIORITY_WORKER_CALLBACK,
+                                  [worker](Reactor *) { worker->coroutine_num = Coroutine::count(); });
     }
 
     worker->status = SW_WORKER_IDLE;
@@ -656,7 +660,7 @@ _read_from_pipe:
 
         recv_n = readv(event->fd, buffers, 2);
         if (recv_n == 0) {
-            swWarn("receive pipeline data error, pipe_fd=%d, reactor_id=%d", event->fd, info->reactor_id);
+            swoole_warning("receive pipeline data error, pipe_fd=%d, reactor_id=%d", event->fd, info->reactor_id);
             return SW_ERR;
         }
         if (recv_n < 0 && event->socket->catch_error(errno) == SW_WAIT) {
@@ -664,7 +668,7 @@ _read_from_pipe:
         }
         if (recv_n > 0) {
             worker_buffer->length += (recv_n - sizeof(pipe_buffer->info));
-            swTrace("append msgid=%ld, buffer=%p, n=%ld", pipe_buffer->info.msg_id, worker_buffer, recv_n);
+            swoole_trace("append msgid=%ld, buffer=%p, n=%ld", pipe_buffer->info.msg_id, worker_buffer, recv_n);
         }
 
         recv_chunk_count++;
@@ -678,7 +682,7 @@ _read_from_pipe:
              * the maximum number of consecutive chunks received by the worker is limited.
              */
             if (recv_chunk_count >= SW_WORKER_MAX_RECV_CHUNK_COUNT) {
-                swTraceLog(SW_TRACE_WORKER,
+                swoole_trace_log(SW_TRACE_WORKER,
                            "worker process[%u] receives the chunk data to the maximum[%d], return to event loop",
                            SwooleG.process_id,
                            recv_chunk_count);
@@ -693,7 +697,7 @@ _read_from_pipe:
              */
             pipe_buffer->info.flags |= SW_EVENT_DATA_OBJ_PTR;
             memcpy(pipe_buffer->data, &worker_buffer, sizeof(worker_buffer));
-            swTrace("msg_id=%ld, len=%u", pipe_buffer->info.msg_id, pipe_buffer->info.len);
+            swoole_trace("msg_id=%ld, len=%u", pipe_buffer->info.msg_id, pipe_buffer->info.len);
         }
     } else {
         recv_n = event->socket->read(pipe_buffer, serv->ipc_max_size);
